# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class PtsV2PaymentsPost201ResponseConsumerAuthenticationInformationIvr(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'enabled_message': 'bool',
        'encryption_key': 'str',
        'encryption_mandatory': 'bool',
        'encryption_type': 'str',
        'label': 'str',
        'prompt': 'str',
        'status_message': 'str'
    }

    attribute_map = {
        'enabled_message': 'enabledMessage',
        'encryption_key': 'encryptionKey',
        'encryption_mandatory': 'encryptionMandatory',
        'encryption_type': 'encryptionType',
        'label': 'label',
        'prompt': 'prompt',
        'status_message': 'statusMessage'
    }

    def __init__(self, enabled_message=None, encryption_key=None, encryption_mandatory=None, encryption_type=None, label=None, prompt=None, status_message=None):
        """
        PtsV2PaymentsPost201ResponseConsumerAuthenticationInformationIvr - a model defined in Swagger
        """

        self._enabled_message = None
        self._encryption_key = None
        self._encryption_mandatory = None
        self._encryption_type = None
        self._label = None
        self._prompt = None
        self._status_message = None

        if enabled_message is not None:
          self.enabled_message = enabled_message
        if encryption_key is not None:
          self.encryption_key = encryption_key
        if encryption_mandatory is not None:
          self.encryption_mandatory = encryption_mandatory
        if encryption_type is not None:
          self.encryption_type = encryption_type
        if label is not None:
          self.label = label
        if prompt is not None:
          self.prompt = prompt
        if status_message is not None:
          self.status_message = status_message

    @property
    def enabled_message(self):
        """
        Gets the enabled_message of this PtsV2PaymentsPost201ResponseConsumerAuthenticationInformationIvr.
        Flag to indicate if a valid IVR transaction was detected. 

        :return: The enabled_message of this PtsV2PaymentsPost201ResponseConsumerAuthenticationInformationIvr.
        :rtype: bool
        """
        return self._enabled_message

    @enabled_message.setter
    def enabled_message(self, enabled_message):
        """
        Sets the enabled_message of this PtsV2PaymentsPost201ResponseConsumerAuthenticationInformationIvr.
        Flag to indicate if a valid IVR transaction was detected. 

        :param enabled_message: The enabled_message of this PtsV2PaymentsPost201ResponseConsumerAuthenticationInformationIvr.
        :type: bool
        """

        self._enabled_message = enabled_message

    @property
    def encryption_key(self):
        """
        Gets the encryption_key of this PtsV2PaymentsPost201ResponseConsumerAuthenticationInformationIvr.
        Encryption key to be used in the event the ACS requires encryption of the credential field. 

        :return: The encryption_key of this PtsV2PaymentsPost201ResponseConsumerAuthenticationInformationIvr.
        :rtype: str
        """
        return self._encryption_key

    @encryption_key.setter
    def encryption_key(self, encryption_key):
        """
        Sets the encryption_key of this PtsV2PaymentsPost201ResponseConsumerAuthenticationInformationIvr.
        Encryption key to be used in the event the ACS requires encryption of the credential field. 

        :param encryption_key: The encryption_key of this PtsV2PaymentsPost201ResponseConsumerAuthenticationInformationIvr.
        :type: str
        """
        if encryption_key is not None and len(encryption_key) > 16:
            raise ValueError("Invalid value for `encryption_key`, length must be less than or equal to `16`")

        self._encryption_key = encryption_key

    @property
    def encryption_mandatory(self):
        """
        Gets the encryption_mandatory of this PtsV2PaymentsPost201ResponseConsumerAuthenticationInformationIvr.
        Flag to indicate if the ACS requires the credential to be encrypted. 

        :return: The encryption_mandatory of this PtsV2PaymentsPost201ResponseConsumerAuthenticationInformationIvr.
        :rtype: bool
        """
        return self._encryption_mandatory

    @encryption_mandatory.setter
    def encryption_mandatory(self, encryption_mandatory):
        """
        Sets the encryption_mandatory of this PtsV2PaymentsPost201ResponseConsumerAuthenticationInformationIvr.
        Flag to indicate if the ACS requires the credential to be encrypted. 

        :param encryption_mandatory: The encryption_mandatory of this PtsV2PaymentsPost201ResponseConsumerAuthenticationInformationIvr.
        :type: bool
        """

        self._encryption_mandatory = encryption_mandatory

    @property
    def encryption_type(self):
        """
        Gets the encryption_type of this PtsV2PaymentsPost201ResponseConsumerAuthenticationInformationIvr.
        An indicator from the ACS to inform the type of encryption that should be used in the event the ACS requires encryption of the credential field. 

        :return: The encryption_type of this PtsV2PaymentsPost201ResponseConsumerAuthenticationInformationIvr.
        :rtype: str
        """
        return self._encryption_type

    @encryption_type.setter
    def encryption_type(self, encryption_type):
        """
        Sets the encryption_type of this PtsV2PaymentsPost201ResponseConsumerAuthenticationInformationIvr.
        An indicator from the ACS to inform the type of encryption that should be used in the event the ACS requires encryption of the credential field. 

        :param encryption_type: The encryption_type of this PtsV2PaymentsPost201ResponseConsumerAuthenticationInformationIvr.
        :type: str
        """
        if encryption_type is not None and len(encryption_type) > 20:
            raise ValueError("Invalid value for `encryption_type`, length must be less than or equal to `20`")

        self._encryption_type = encryption_type

    @property
    def label(self):
        """
        Gets the label of this PtsV2PaymentsPost201ResponseConsumerAuthenticationInformationIvr.
        An ACS Provided label that can be presented to the Consumer. Recommended use with an application. 

        :return: The label of this PtsV2PaymentsPost201ResponseConsumerAuthenticationInformationIvr.
        :rtype: str
        """
        return self._label

    @label.setter
    def label(self, label):
        """
        Sets the label of this PtsV2PaymentsPost201ResponseConsumerAuthenticationInformationIvr.
        An ACS Provided label that can be presented to the Consumer. Recommended use with an application. 

        :param label: The label of this PtsV2PaymentsPost201ResponseConsumerAuthenticationInformationIvr.
        :type: str
        """
        if label is not None and len(label) > 20:
            raise ValueError("Invalid value for `label`, length must be less than or equal to `20`")

        self._label = label

    @property
    def prompt(self):
        """
        Gets the prompt of this PtsV2PaymentsPost201ResponseConsumerAuthenticationInformationIvr.
        An ACS provided string that can be presented to the Consumer. Recommended use with an application. 

        :return: The prompt of this PtsV2PaymentsPost201ResponseConsumerAuthenticationInformationIvr.
        :rtype: str
        """
        return self._prompt

    @prompt.setter
    def prompt(self, prompt):
        """
        Sets the prompt of this PtsV2PaymentsPost201ResponseConsumerAuthenticationInformationIvr.
        An ACS provided string that can be presented to the Consumer. Recommended use with an application. 

        :param prompt: The prompt of this PtsV2PaymentsPost201ResponseConsumerAuthenticationInformationIvr.
        :type: str
        """
        if prompt is not None and len(prompt) > 80:
            raise ValueError("Invalid value for `prompt`, length must be less than or equal to `80`")

        self._prompt = prompt

    @property
    def status_message(self):
        """
        Gets the status_message of this PtsV2PaymentsPost201ResponseConsumerAuthenticationInformationIvr.
        An ACS provided message that can provide additional information or details. 

        :return: The status_message of this PtsV2PaymentsPost201ResponseConsumerAuthenticationInformationIvr.
        :rtype: str
        """
        return self._status_message

    @status_message.setter
    def status_message(self, status_message):
        """
        Sets the status_message of this PtsV2PaymentsPost201ResponseConsumerAuthenticationInformationIvr.
        An ACS provided message that can provide additional information or details. 

        :param status_message: The status_message of this PtsV2PaymentsPost201ResponseConsumerAuthenticationInformationIvr.
        :type: str
        """
        if status_message is not None and len(status_message) > 80:
            raise ValueError("Invalid value for `status_message`, length must be less than or equal to `80`")

        self._status_message = status_message

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, PtsV2PaymentsPost201ResponseConsumerAuthenticationInformationIvr):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Ptsv2paymentsPaymentInformationFluidData(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'key_serial_number': 'str',
        'descriptor': 'str',
        'value': 'str',
        'encoding': 'str'
    }

    attribute_map = {
        'key_serial_number': 'keySerialNumber',
        'descriptor': 'descriptor',
        'value': 'value',
        'encoding': 'encoding'
    }

    def __init__(self, key_serial_number=None, descriptor=None, value=None, encoding=None):
        """
        Ptsv2paymentsPaymentInformationFluidData - a model defined in Swagger
        """

        self._key_serial_number = None
        self._descriptor = None
        self._value = None
        self._encoding = None

        if key_serial_number is not None:
          self.key_serial_number = key_serial_number
        if descriptor is not None:
          self.descriptor = descriptor
        if value is not None:
          self.value = value
        if encoding is not None:
          self.encoding = encoding

    @property
    def key_serial_number(self):
        """
        Gets the key_serial_number of this Ptsv2paymentsPaymentInformationFluidData.
        The encoded or encrypted value that a payment solution returns for an authorization request. For details about the valid values for a key, see [Creating an Online Authorization](https://developer.cybersource.com/api/developer-guides/dita-payments/CreatingOnlineAuth.html) 

        :return: The key_serial_number of this Ptsv2paymentsPaymentInformationFluidData.
        :rtype: str
        """
        return self._key_serial_number

    @key_serial_number.setter
    def key_serial_number(self, key_serial_number):
        """
        Sets the key_serial_number of this Ptsv2paymentsPaymentInformationFluidData.
        The encoded or encrypted value that a payment solution returns for an authorization request. For details about the valid values for a key, see [Creating an Online Authorization](https://developer.cybersource.com/api/developer-guides/dita-payments/CreatingOnlineAuth.html) 

        :param key_serial_number: The key_serial_number of this Ptsv2paymentsPaymentInformationFluidData.
        :type: str
        """

        self._key_serial_number = key_serial_number

    @property
    def descriptor(self):
        """
        Gets the descriptor of this Ptsv2paymentsPaymentInformationFluidData.
        The identifier for a payment solution, which is sending the encrypted payment data for decryption. Valid values: - Samsung Pay: `RklEPUNPTU1PTi5TQU1TVU5HLklOQVBQLlBBWU1FTlQ=`  **Note**: For other payment solutions, the value may be specific to the customer's mobile device. For example, the descriptor for a Bluefin payment encryption would be a device-generated descriptor.  #### Used by **Authorization and Standalone Credits** Required for authorizations and standalone credits that use Bluefin PCI P2PE.  #### Card Present processing Format of the encrypted payment data. The value for Bluefin PCI P2PE is `Ymx1ZWZpbg==`. 

        :return: The descriptor of this Ptsv2paymentsPaymentInformationFluidData.
        :rtype: str
        """
        return self._descriptor

    @descriptor.setter
    def descriptor(self, descriptor):
        """
        Sets the descriptor of this Ptsv2paymentsPaymentInformationFluidData.
        The identifier for a payment solution, which is sending the encrypted payment data for decryption. Valid values: - Samsung Pay: `RklEPUNPTU1PTi5TQU1TVU5HLklOQVBQLlBBWU1FTlQ=`  **Note**: For other payment solutions, the value may be specific to the customer's mobile device. For example, the descriptor for a Bluefin payment encryption would be a device-generated descriptor.  #### Used by **Authorization and Standalone Credits** Required for authorizations and standalone credits that use Bluefin PCI P2PE.  #### Card Present processing Format of the encrypted payment data. The value for Bluefin PCI P2PE is `Ymx1ZWZpbg==`. 

        :param descriptor: The descriptor of this Ptsv2paymentsPaymentInformationFluidData.
        :type: str
        """
        if descriptor is not None and len(descriptor) > 128:
            raise ValueError("Invalid value for `descriptor`, length must be less than or equal to `128`")

        self._descriptor = descriptor

    @property
    def value(self):
        """
        Gets the value of this Ptsv2paymentsPaymentInformationFluidData.
        Represents the encrypted payment data BLOB. The entry for this field is dependent on the payment solution a merchant uses.  #### Used by **Authorization and Standalone Credits** Required for authorizations and standalone credits that use Bluefin PCI P2PE.  #### Card Present processing This field represents the encrypted Bluefin PCI P2PE payment data. Obtain the encrypted payment data from a Bluefin-supported device. 

        :return: The value of this Ptsv2paymentsPaymentInformationFluidData.
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """
        Sets the value of this Ptsv2paymentsPaymentInformationFluidData.
        Represents the encrypted payment data BLOB. The entry for this field is dependent on the payment solution a merchant uses.  #### Used by **Authorization and Standalone Credits** Required for authorizations and standalone credits that use Bluefin PCI P2PE.  #### Card Present processing This field represents the encrypted Bluefin PCI P2PE payment data. Obtain the encrypted payment data from a Bluefin-supported device. 

        :param value: The value of this Ptsv2paymentsPaymentInformationFluidData.
        :type: str
        """
        if value is not None and len(value) > 3072:
            raise ValueError("Invalid value for `value`, length must be less than or equal to `3072`")

        self._value = value

    @property
    def encoding(self):
        """
        Gets the encoding of this Ptsv2paymentsPaymentInformationFluidData.
        Encoding method used to encrypt the payment data.  Valid value: Base64 

        :return: The encoding of this Ptsv2paymentsPaymentInformationFluidData.
        :rtype: str
        """
        return self._encoding

    @encoding.setter
    def encoding(self, encoding):
        """
        Sets the encoding of this Ptsv2paymentsPaymentInformationFluidData.
        Encoding method used to encrypt the payment data.  Valid value: Base64 

        :param encoding: The encoding of this Ptsv2paymentsPaymentInformationFluidData.
        :type: str
        """
        if encoding is not None and len(encoding) > 6:
            raise ValueError("Invalid value for `encoding`, length must be less than or equal to `6`")

        self._encoding = encoding

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Ptsv2paymentsPaymentInformationFluidData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Ptsv2paymentsAggregatorInformationSubMerchant(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'card_acceptor_id': 'str',
        'id': 'str',
        'name': 'str',
        'address1': 'str',
        'locality': 'str',
        'administrative_area': 'str',
        'region': 'str',
        'postal_code': 'str',
        'country': 'str',
        'email': 'str',
        'phone_number': 'str'
    }

    attribute_map = {
        'card_acceptor_id': 'cardAcceptorId',
        'id': 'id',
        'name': 'name',
        'address1': 'address1',
        'locality': 'locality',
        'administrative_area': 'administrativeArea',
        'region': 'region',
        'postal_code': 'postalCode',
        'country': 'country',
        'email': 'email',
        'phone_number': 'phoneNumber'
    }

    def __init__(self, card_acceptor_id=None, id=None, name=None, address1=None, locality=None, administrative_area=None, region=None, postal_code=None, country=None, email=None, phone_number=None):
        """
        Ptsv2paymentsAggregatorInformationSubMerchant - a model defined in Swagger
        """

        self._card_acceptor_id = None
        self._id = None
        self._name = None
        self._address1 = None
        self._locality = None
        self._administrative_area = None
        self._region = None
        self._postal_code = None
        self._country = None
        self._email = None
        self._phone_number = None

        if card_acceptor_id is not None:
          self.card_acceptor_id = card_acceptor_id
        if id is not None:
          self.id = id
        if name is not None:
          self.name = name
        if address1 is not None:
          self.address1 = address1
        if locality is not None:
          self.locality = locality
        if administrative_area is not None:
          self.administrative_area = administrative_area
        if region is not None:
          self.region = region
        if postal_code is not None:
          self.postal_code = postal_code
        if country is not None:
          self.country = country
        if email is not None:
          self.email = email
        if phone_number is not None:
          self.phone_number = phone_number

    @property
    def card_acceptor_id(self):
        """
        Gets the card_acceptor_id of this Ptsv2paymentsAggregatorInformationSubMerchant.
        Unique identifier assigned by the payment card company to the sub-merchant.

        :return: The card_acceptor_id of this Ptsv2paymentsAggregatorInformationSubMerchant.
        :rtype: str
        """
        return self._card_acceptor_id

    @card_acceptor_id.setter
    def card_acceptor_id(self, card_acceptor_id):
        """
        Sets the card_acceptor_id of this Ptsv2paymentsAggregatorInformationSubMerchant.
        Unique identifier assigned by the payment card company to the sub-merchant.

        :param card_acceptor_id: The card_acceptor_id of this Ptsv2paymentsAggregatorInformationSubMerchant.
        :type: str
        """
        if card_acceptor_id is not None and len(card_acceptor_id) > 15:
            raise ValueError("Invalid value for `card_acceptor_id`, length must be less than or equal to `15`")

        self._card_acceptor_id = card_acceptor_id

    @property
    def id(self):
        """
        Gets the id of this Ptsv2paymentsAggregatorInformationSubMerchant.
        The ID you assigned to your sub-merchant. CyberSource through VisaNet: For American Express transaction, the value for this field corresponds to the following data in the TC 33 capture file: - Record: CP01 TCRB - Position: 65-84 - Field: American Express Seller ID For  Mastercard transactions, the value for this field corresponds to the following data in the TC 33 capture file: - Record: CP01 TCR6 - Position: 117-131 - Field: Mastercard Sub-Merchant ID FDC Compass: This value must consist of uppercase characters.  American Express Direct: String (20) CyberSource through VisaNet with American Express: String (20) CyberSource through VisaNet with Mastercard: String (15) FDC Compass: String (20) FDC Nashville Global: String (14) 

        :return: The id of this Ptsv2paymentsAggregatorInformationSubMerchant.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Ptsv2paymentsAggregatorInformationSubMerchant.
        The ID you assigned to your sub-merchant. CyberSource through VisaNet: For American Express transaction, the value for this field corresponds to the following data in the TC 33 capture file: - Record: CP01 TCRB - Position: 65-84 - Field: American Express Seller ID For  Mastercard transactions, the value for this field corresponds to the following data in the TC 33 capture file: - Record: CP01 TCR6 - Position: 117-131 - Field: Mastercard Sub-Merchant ID FDC Compass: This value must consist of uppercase characters.  American Express Direct: String (20) CyberSource through VisaNet with American Express: String (20) CyberSource through VisaNet with Mastercard: String (15) FDC Compass: String (20) FDC Nashville Global: String (14) 

        :param id: The id of this Ptsv2paymentsAggregatorInformationSubMerchant.
        :type: str
        """
        if id is not None and len(id) > 20:
            raise ValueError("Invalid value for `id`, length must be less than or equal to `20`")

        self._id = id

    @property
    def name(self):
        """
        Gets the name of this Ptsv2paymentsAggregatorInformationSubMerchant.
        Sub-merchant’s business name.  #### American Express Direct The maximum length of the sub-merchant name depends on the length of the aggregator name. The combined length for both values must not exceed 36 characters.  #### CyberSource through VisaNet With American Express, the maximum length of the sub-merchant name depends on the length of the aggregator name. The combined length for both values must not exceed 36 characters. The value for this field does not map to the TC 33 capture file5.  #### FDC Compass This value must consist of uppercase characters.  #### FDC Nashville Global With Mastercard, the maximum length of the sub-merchant name depends on the length of the aggregator name: - If aggregator name length is 1 through 3, maximum sub-merchant name length is 21. - If aggregator name length is 4 through 7, maximum sub-merchant name length is 17. - If aggregator name length is 8 through 12, maximum sub-merchant name length is 12. 

        :return: The name of this Ptsv2paymentsAggregatorInformationSubMerchant.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Ptsv2paymentsAggregatorInformationSubMerchant.
        Sub-merchant’s business name.  #### American Express Direct The maximum length of the sub-merchant name depends on the length of the aggregator name. The combined length for both values must not exceed 36 characters.  #### CyberSource through VisaNet With American Express, the maximum length of the sub-merchant name depends on the length of the aggregator name. The combined length for both values must not exceed 36 characters. The value for this field does not map to the TC 33 capture file5.  #### FDC Compass This value must consist of uppercase characters.  #### FDC Nashville Global With Mastercard, the maximum length of the sub-merchant name depends on the length of the aggregator name: - If aggregator name length is 1 through 3, maximum sub-merchant name length is 21. - If aggregator name length is 4 through 7, maximum sub-merchant name length is 17. - If aggregator name length is 8 through 12, maximum sub-merchant name length is 12. 

        :param name: The name of this Ptsv2paymentsAggregatorInformationSubMerchant.
        :type: str
        """
        if name is not None and len(name) > 37:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `37`")

        self._name = name

    @property
    def address1(self):
        """
        Gets the address1 of this Ptsv2paymentsAggregatorInformationSubMerchant.
        First line of the sub-merchant’s street address.  For processor-specific details, see `submerchant_street` field description in [Credit Card Services Using the SCMP API.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  #### CyberSource through VisaNet The value for this field does not map to the TC 33 capture file5.  #### FDC Compass This value must consist of uppercase characters. 

        :return: The address1 of this Ptsv2paymentsAggregatorInformationSubMerchant.
        :rtype: str
        """
        return self._address1

    @address1.setter
    def address1(self, address1):
        """
        Sets the address1 of this Ptsv2paymentsAggregatorInformationSubMerchant.
        First line of the sub-merchant’s street address.  For processor-specific details, see `submerchant_street` field description in [Credit Card Services Using the SCMP API.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  #### CyberSource through VisaNet The value for this field does not map to the TC 33 capture file5.  #### FDC Compass This value must consist of uppercase characters. 

        :param address1: The address1 of this Ptsv2paymentsAggregatorInformationSubMerchant.
        :type: str
        """
        if address1 is not None and len(address1) > 38:
            raise ValueError("Invalid value for `address1`, length must be less than or equal to `38`")

        self._address1 = address1

    @property
    def locality(self):
        """
        Gets the locality of this Ptsv2paymentsAggregatorInformationSubMerchant.
        Sub-merchant’s city.  For processor-specific details, see `submerchant_city` request field description in [Credit Card Services Using the SCMP API.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  #### CyberSource through VisaNet The value for this field does not map to the TC 33 capture file5.  #### FDC Compass This value must consist of uppercase characters. 

        :return: The locality of this Ptsv2paymentsAggregatorInformationSubMerchant.
        :rtype: str
        """
        return self._locality

    @locality.setter
    def locality(self, locality):
        """
        Sets the locality of this Ptsv2paymentsAggregatorInformationSubMerchant.
        Sub-merchant’s city.  For processor-specific details, see `submerchant_city` request field description in [Credit Card Services Using the SCMP API.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  #### CyberSource through VisaNet The value for this field does not map to the TC 33 capture file5.  #### FDC Compass This value must consist of uppercase characters. 

        :param locality: The locality of this Ptsv2paymentsAggregatorInformationSubMerchant.
        :type: str
        """
        if locality is not None and len(locality) > 21:
            raise ValueError("Invalid value for `locality`, length must be less than or equal to `21`")

        self._locality = locality

    @property
    def administrative_area(self):
        """
        Gets the administrative_area of this Ptsv2paymentsAggregatorInformationSubMerchant.
        Sub-merchant’s state or province.  For possible values and also aggregator support, see `submerchant_state` request field description in [Credit Card Services Using the SCMP API.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  #### CyberSource through VisaNet The value for this field does not map to the TC 33 capture file5.  #### FDC Compass This value must consist of uppercase characters. 

        :return: The administrative_area of this Ptsv2paymentsAggregatorInformationSubMerchant.
        :rtype: str
        """
        return self._administrative_area

    @administrative_area.setter
    def administrative_area(self, administrative_area):
        """
        Sets the administrative_area of this Ptsv2paymentsAggregatorInformationSubMerchant.
        Sub-merchant’s state or province.  For possible values and also aggregator support, see `submerchant_state` request field description in [Credit Card Services Using the SCMP API.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  #### CyberSource through VisaNet The value for this field does not map to the TC 33 capture file5.  #### FDC Compass This value must consist of uppercase characters. 

        :param administrative_area: The administrative_area of this Ptsv2paymentsAggregatorInformationSubMerchant.
        :type: str
        """
        if administrative_area is not None and len(administrative_area) > 3:
            raise ValueError("Invalid value for `administrative_area`, length must be less than or equal to `3`")

        self._administrative_area = administrative_area

    @property
    def region(self):
        """
        Gets the region of this Ptsv2paymentsAggregatorInformationSubMerchant.
        Sub-merchant’s region.  **Example**\\ `NE` indicates that the sub-merchant is in the northeast region.  For processor-specific details, see `submerchant_region` request field description in [Credit Card Services Using the SCMP API.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/) 

        :return: The region of this Ptsv2paymentsAggregatorInformationSubMerchant.
        :rtype: str
        """
        return self._region

    @region.setter
    def region(self, region):
        """
        Sets the region of this Ptsv2paymentsAggregatorInformationSubMerchant.
        Sub-merchant’s region.  **Example**\\ `NE` indicates that the sub-merchant is in the northeast region.  For processor-specific details, see `submerchant_region` request field description in [Credit Card Services Using the SCMP API.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/) 

        :param region: The region of this Ptsv2paymentsAggregatorInformationSubMerchant.
        :type: str
        """
        if region is not None and len(region) > 3:
            raise ValueError("Invalid value for `region`, length must be less than or equal to `3`")

        self._region = region

    @property
    def postal_code(self):
        """
        Gets the postal_code of this Ptsv2paymentsAggregatorInformationSubMerchant.
        Partial postal code for the sub-merchant’s address.  For processor-specific details, see `submerchant_postal_code` request field description in [Credit Card Services Using the SCMP API.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  #### CyberSource through VisaNet The value for this field does not map to the TC 33 capture file5.  #### FDC Compass This value must consist of uppercase characters. 

        :return: The postal_code of this Ptsv2paymentsAggregatorInformationSubMerchant.
        :rtype: str
        """
        return self._postal_code

    @postal_code.setter
    def postal_code(self, postal_code):
        """
        Sets the postal_code of this Ptsv2paymentsAggregatorInformationSubMerchant.
        Partial postal code for the sub-merchant’s address.  For processor-specific details, see `submerchant_postal_code` request field description in [Credit Card Services Using the SCMP API.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  #### CyberSource through VisaNet The value for this field does not map to the TC 33 capture file5.  #### FDC Compass This value must consist of uppercase characters. 

        :param postal_code: The postal_code of this Ptsv2paymentsAggregatorInformationSubMerchant.
        :type: str
        """
        if postal_code is not None and len(postal_code) > 15:
            raise ValueError("Invalid value for `postal_code`, length must be less than or equal to `15`")

        self._postal_code = postal_code

    @property
    def country(self):
        """
        Gets the country of this Ptsv2paymentsAggregatorInformationSubMerchant.
        Sub-merchant’s country. Use the [ISO Standard Country Codes](https://developer.cybersource.com/library/documentation/sbc/quickref/countries_alpha_list.pdf).  #### CyberSource through VisaNet The value for this field does not map to the TC 33 capture file.  #### FDC Compass This value must consist of uppercase characters.  For details, see the `submerchant_country` request-level field description in [Credit Card Services Using the SCMP API.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/) 

        :return: The country of this Ptsv2paymentsAggregatorInformationSubMerchant.
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """
        Sets the country of this Ptsv2paymentsAggregatorInformationSubMerchant.
        Sub-merchant’s country. Use the [ISO Standard Country Codes](https://developer.cybersource.com/library/documentation/sbc/quickref/countries_alpha_list.pdf).  #### CyberSource through VisaNet The value for this field does not map to the TC 33 capture file.  #### FDC Compass This value must consist of uppercase characters.  For details, see the `submerchant_country` request-level field description in [Credit Card Services Using the SCMP API.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/) 

        :param country: The country of this Ptsv2paymentsAggregatorInformationSubMerchant.
        :type: str
        """
        if country is not None and len(country) > 3:
            raise ValueError("Invalid value for `country`, length must be less than or equal to `3`")

        self._country = country

    @property
    def email(self):
        """
        Gets the email of this Ptsv2paymentsAggregatorInformationSubMerchant.
        Sub-merchant’s email address.  **Maximum length for processors**   - American Express Direct: 40  - CyberSource through VisaNet: 40  - FDC Compass: 40  - FDC Nashville Global: 19  #### CyberSource through VisaNet With American Express, the value for this field corresponds to the following data in the TC 33 capture file: - Record: CP01 TCRB - Position: 25-64 - Field: American Express Seller E-mail Address  **Note** The TC 33 Capture file contains information about the purchases and refunds that a merchant submits to CyberSource. CyberSource through VisaNet creates the TC 33 Capture file at the end of the day and sends it to the merchant’s acquirer, who uses this information to facilitate end-of-day clearing processing with payment card companies. 

        :return: The email of this Ptsv2paymentsAggregatorInformationSubMerchant.
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """
        Sets the email of this Ptsv2paymentsAggregatorInformationSubMerchant.
        Sub-merchant’s email address.  **Maximum length for processors**   - American Express Direct: 40  - CyberSource through VisaNet: 40  - FDC Compass: 40  - FDC Nashville Global: 19  #### CyberSource through VisaNet With American Express, the value for this field corresponds to the following data in the TC 33 capture file: - Record: CP01 TCRB - Position: 25-64 - Field: American Express Seller E-mail Address  **Note** The TC 33 Capture file contains information about the purchases and refunds that a merchant submits to CyberSource. CyberSource through VisaNet creates the TC 33 Capture file at the end of the day and sends it to the merchant’s acquirer, who uses this information to facilitate end-of-day clearing processing with payment card companies. 

        :param email: The email of this Ptsv2paymentsAggregatorInformationSubMerchant.
        :type: str
        """
        if email is not None and len(email) > 40:
            raise ValueError("Invalid value for `email`, length must be less than or equal to `40`")

        self._email = email

    @property
    def phone_number(self):
        """
        Gets the phone_number of this Ptsv2paymentsAggregatorInformationSubMerchant.
        Sub-merchant’s telephone number.  **Maximum length for procesors**   - American Express Direct: 20  - CyberSource through VisaNet: 20  - FDC Compass: 13  - FDC Nashville Global: 10  #### CyberSource through VisaNet With American Express, the value for this field corresponds to the following data in the TC 33 capture file5: - Record: CP01 TCRB - Position: 5-24 - Field: American Express Seller Telephone Number  **FDC Compass**\\ This value must consist of uppercase characters. Use one of these recommended formats:\\ `NNN-NNN-NNNN`\\ `NNN-AAAAAAA` 

        :return: The phone_number of this Ptsv2paymentsAggregatorInformationSubMerchant.
        :rtype: str
        """
        return self._phone_number

    @phone_number.setter
    def phone_number(self, phone_number):
        """
        Sets the phone_number of this Ptsv2paymentsAggregatorInformationSubMerchant.
        Sub-merchant’s telephone number.  **Maximum length for procesors**   - American Express Direct: 20  - CyberSource through VisaNet: 20  - FDC Compass: 13  - FDC Nashville Global: 10  #### CyberSource through VisaNet With American Express, the value for this field corresponds to the following data in the TC 33 capture file5: - Record: CP01 TCRB - Position: 5-24 - Field: American Express Seller Telephone Number  **FDC Compass**\\ This value must consist of uppercase characters. Use one of these recommended formats:\\ `NNN-NNN-NNNN`\\ `NNN-AAAAAAA` 

        :param phone_number: The phone_number of this Ptsv2paymentsAggregatorInformationSubMerchant.
        :type: str
        """
        if phone_number is not None and len(phone_number) > 20:
            raise ValueError("Invalid value for `phone_number`, length must be less than or equal to `20`")

        self._phone_number = phone_number

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Ptsv2paymentsAggregatorInformationSubMerchant):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Ptsv2paymentsRiskInformationBuyerHistoryAccountHistory(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'first_use_of_shipping_address': 'bool',
        'shipping_address_usage_date': 'str'
    }

    attribute_map = {
        'first_use_of_shipping_address': 'firstUseOfShippingAddress',
        'shipping_address_usage_date': 'shippingAddressUsageDate'
    }

    def __init__(self, first_use_of_shipping_address=None, shipping_address_usage_date=None):
        """
        Ptsv2paymentsRiskInformationBuyerHistoryAccountHistory - a model defined in Swagger
        """

        self._first_use_of_shipping_address = None
        self._shipping_address_usage_date = None

        if first_use_of_shipping_address is not None:
          self.first_use_of_shipping_address = first_use_of_shipping_address
        if shipping_address_usage_date is not None:
          self.shipping_address_usage_date = shipping_address_usage_date

    @property
    def first_use_of_shipping_address(self):
        """
        Gets the first_use_of_shipping_address of this Ptsv2paymentsRiskInformationBuyerHistoryAccountHistory.
        Applicable when this is not a guest account. 

        :return: The first_use_of_shipping_address of this Ptsv2paymentsRiskInformationBuyerHistoryAccountHistory.
        :rtype: bool
        """
        return self._first_use_of_shipping_address

    @first_use_of_shipping_address.setter
    def first_use_of_shipping_address(self, first_use_of_shipping_address):
        """
        Sets the first_use_of_shipping_address of this Ptsv2paymentsRiskInformationBuyerHistoryAccountHistory.
        Applicable when this is not a guest account. 

        :param first_use_of_shipping_address: The first_use_of_shipping_address of this Ptsv2paymentsRiskInformationBuyerHistoryAccountHistory.
        :type: bool
        """

        self._first_use_of_shipping_address = first_use_of_shipping_address

    @property
    def shipping_address_usage_date(self):
        """
        Gets the shipping_address_usage_date of this Ptsv2paymentsRiskInformationBuyerHistoryAccountHistory.
        Date when the shipping address for this transaction was first used. Recommended for Discover ProtectBuy. If `firstUseOfShippingAddress` is false and not a guest account, then this date is entered. 

        :return: The shipping_address_usage_date of this Ptsv2paymentsRiskInformationBuyerHistoryAccountHistory.
        :rtype: str
        """
        return self._shipping_address_usage_date

    @shipping_address_usage_date.setter
    def shipping_address_usage_date(self, shipping_address_usage_date):
        """
        Sets the shipping_address_usage_date of this Ptsv2paymentsRiskInformationBuyerHistoryAccountHistory.
        Date when the shipping address for this transaction was first used. Recommended for Discover ProtectBuy. If `firstUseOfShippingAddress` is false and not a guest account, then this date is entered. 

        :param shipping_address_usage_date: The shipping_address_usage_date of this Ptsv2paymentsRiskInformationBuyerHistoryAccountHistory.
        :type: str
        """
        if shipping_address_usage_date is not None and len(shipping_address_usage_date) > 10:
            raise ValueError("Invalid value for `shipping_address_usage_date`, length must be less than or equal to `10`")

        self._shipping_address_usage_date = shipping_address_usage_date

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Ptsv2paymentsRiskInformationBuyerHistoryAccountHistory):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Ptsv2paymentsidcapturesBuyerInformation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'merchant_customer_id': 'str',
        'vat_registration_number': 'str'
    }

    attribute_map = {
        'merchant_customer_id': 'merchantCustomerId',
        'vat_registration_number': 'vatRegistrationNumber'
    }

    def __init__(self, merchant_customer_id=None, vat_registration_number=None):
        """
        Ptsv2paymentsidcapturesBuyerInformation - a model defined in Swagger
        """

        self._merchant_customer_id = None
        self._vat_registration_number = None

        if merchant_customer_id is not None:
          self.merchant_customer_id = merchant_customer_id
        if vat_registration_number is not None:
          self.vat_registration_number = vat_registration_number

    @property
    def merchant_customer_id(self):
        """
        Gets the merchant_customer_id of this Ptsv2paymentsidcapturesBuyerInformation.
        Your identifier for the customer.  When a subscription or customer profile is being created, the maximum length for this field for most processors is 30. Otherwise, the maximum length is 100.  #### Comercio Latino For recurring payments in Mexico, the value is the customer’s contract number. Note Before you request the authorization, you must inform the issuer of the customer contract numbers that will be used for recurring transactions.  #### Worldpay VAP For a follow-on credit with Worldpay VAP, CyberSource checks the following locations, in the order given, for a customer account ID value and uses the first value it finds: 1. `customer_account_id` value in the follow-on credit request 2. Customer account ID value that was used for the capture that is being credited 3. Customer account ID value that was used for the original authorization If a customer account ID value cannot be found in any of these locations, then no value is used.  For processor-specific information, see the `customer_account_id` field description in [Credit Card Services Using the SCMP API.](http://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html) 

        :return: The merchant_customer_id of this Ptsv2paymentsidcapturesBuyerInformation.
        :rtype: str
        """
        return self._merchant_customer_id

    @merchant_customer_id.setter
    def merchant_customer_id(self, merchant_customer_id):
        """
        Sets the merchant_customer_id of this Ptsv2paymentsidcapturesBuyerInformation.
        Your identifier for the customer.  When a subscription or customer profile is being created, the maximum length for this field for most processors is 30. Otherwise, the maximum length is 100.  #### Comercio Latino For recurring payments in Mexico, the value is the customer’s contract number. Note Before you request the authorization, you must inform the issuer of the customer contract numbers that will be used for recurring transactions.  #### Worldpay VAP For a follow-on credit with Worldpay VAP, CyberSource checks the following locations, in the order given, for a customer account ID value and uses the first value it finds: 1. `customer_account_id` value in the follow-on credit request 2. Customer account ID value that was used for the capture that is being credited 3. Customer account ID value that was used for the original authorization If a customer account ID value cannot be found in any of these locations, then no value is used.  For processor-specific information, see the `customer_account_id` field description in [Credit Card Services Using the SCMP API.](http://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html) 

        :param merchant_customer_id: The merchant_customer_id of this Ptsv2paymentsidcapturesBuyerInformation.
        :type: str
        """
        if merchant_customer_id is not None and len(merchant_customer_id) > 100:
            raise ValueError("Invalid value for `merchant_customer_id`, length must be less than or equal to `100`")

        self._merchant_customer_id = merchant_customer_id

    @property
    def vat_registration_number(self):
        """
        Gets the vat_registration_number of this Ptsv2paymentsidcapturesBuyerInformation.
        Customer’s government-assigned tax identification number.  #### Tax Calculation Optional for international and value added taxes only. Not applicable to U.S. and Canadian taxes.  For processor-specific information, see the purchaser_vat_registration_number field in [Level II and Level III Processing Using the SCMP API.](http://apps.cybersource.com/library/documentation/dev_guides/Level_2_3_SCMP_API/html) 

        :return: The vat_registration_number of this Ptsv2paymentsidcapturesBuyerInformation.
        :rtype: str
        """
        return self._vat_registration_number

    @vat_registration_number.setter
    def vat_registration_number(self, vat_registration_number):
        """
        Sets the vat_registration_number of this Ptsv2paymentsidcapturesBuyerInformation.
        Customer’s government-assigned tax identification number.  #### Tax Calculation Optional for international and value added taxes only. Not applicable to U.S. and Canadian taxes.  For processor-specific information, see the purchaser_vat_registration_number field in [Level II and Level III Processing Using the SCMP API.](http://apps.cybersource.com/library/documentation/dev_guides/Level_2_3_SCMP_API/html) 

        :param vat_registration_number: The vat_registration_number of this Ptsv2paymentsidcapturesBuyerInformation.
        :type: str
        """
        if vat_registration_number is not None and len(vat_registration_number) > 20:
            raise ValueError("Invalid value for `vat_registration_number`, length must be less than or equal to `20`")

        self._vat_registration_number = vat_registration_number

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Ptsv2paymentsidcapturesBuyerInformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class PtsV2PaymentsRefundPost201ResponseRefundAmountDetails(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'refund_amount': 'str',
        'currency': 'str'
    }

    attribute_map = {
        'refund_amount': 'refundAmount',
        'currency': 'currency'
    }

    def __init__(self, refund_amount=None, currency=None):
        """
        PtsV2PaymentsRefundPost201ResponseRefundAmountDetails - a model defined in Swagger
        """

        self._refund_amount = None
        self._currency = None

        if refund_amount is not None:
          self.refund_amount = refund_amount
        if currency is not None:
          self.currency = currency

    @property
    def refund_amount(self):
        """
        Gets the refund_amount of this PtsV2PaymentsRefundPost201ResponseRefundAmountDetails.
        Total amount of the refund.

        :return: The refund_amount of this PtsV2PaymentsRefundPost201ResponseRefundAmountDetails.
        :rtype: str
        """
        return self._refund_amount

    @refund_amount.setter
    def refund_amount(self, refund_amount):
        """
        Sets the refund_amount of this PtsV2PaymentsRefundPost201ResponseRefundAmountDetails.
        Total amount of the refund.

        :param refund_amount: The refund_amount of this PtsV2PaymentsRefundPost201ResponseRefundAmountDetails.
        :type: str
        """
        if refund_amount is not None and len(refund_amount) > 15:
            raise ValueError("Invalid value for `refund_amount`, length must be less than or equal to `15`")

        self._refund_amount = refund_amount

    @property
    def currency(self):
        """
        Gets the currency of this PtsV2PaymentsRefundPost201ResponseRefundAmountDetails.
        Currency used for the order. Use the three-character [ISO Standard Currency Codes.](http://apps.cybersource.com/library/documentation/sbc/quickref/currencies.pdf)  #### Used by **Authorization** Required field.  **Authorization Reversal** For an authorization reversal (`reversalInformation`) or a capture (`processingOptions.capture` is set to `true`), you must use the same currency that you used in your payment authorization request.  #### PIN Debit Currency for the amount you requested for the PIN debit purchase. This value is returned for partial authorizations. The issuing bank can approve a partial amount if the balance on the debit card is less than the requested transaction amount. For the possible values, see the [ISO Standard Currency Codes](https://developer.cybersource.com/library/documentation/sbc/quickref/currencies.pdf). Returned by PIN debit purchase.  For PIN debit reversal requests, you must use the same currency that was used for the PIN debit purchase or PIN debit credit that you are reversing. For the possible values, see the [ISO Standard Currency Codes](https://developer.cybersource.com/library/documentation/sbc/quickref/currencies.pdf).  Required field for PIN Debit purchase and PIN Debit credit requests. Optional field for PIN Debit reversal requests.  #### GPX This field is optional for reversing an authorization or credit.  #### DCC for First Data Your local currency. For details, see the `currency` field description in [Dynamic Currency Conversion For First Data Using the SCMP API](http://apps.cybersource.com/library/documentation/dev_guides/DCC_FirstData_SCMP/DCC_FirstData_SCMP_API.pdf).  #### Tax Calculation Required for international tax and value added tax only. Optional for U.S. and Canadian taxes. Your local currency. 

        :return: The currency of this PtsV2PaymentsRefundPost201ResponseRefundAmountDetails.
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """
        Sets the currency of this PtsV2PaymentsRefundPost201ResponseRefundAmountDetails.
        Currency used for the order. Use the three-character [ISO Standard Currency Codes.](http://apps.cybersource.com/library/documentation/sbc/quickref/currencies.pdf)  #### Used by **Authorization** Required field.  **Authorization Reversal** For an authorization reversal (`reversalInformation`) or a capture (`processingOptions.capture` is set to `true`), you must use the same currency that you used in your payment authorization request.  #### PIN Debit Currency for the amount you requested for the PIN debit purchase. This value is returned for partial authorizations. The issuing bank can approve a partial amount if the balance on the debit card is less than the requested transaction amount. For the possible values, see the [ISO Standard Currency Codes](https://developer.cybersource.com/library/documentation/sbc/quickref/currencies.pdf). Returned by PIN debit purchase.  For PIN debit reversal requests, you must use the same currency that was used for the PIN debit purchase or PIN debit credit that you are reversing. For the possible values, see the [ISO Standard Currency Codes](https://developer.cybersource.com/library/documentation/sbc/quickref/currencies.pdf).  Required field for PIN Debit purchase and PIN Debit credit requests. Optional field for PIN Debit reversal requests.  #### GPX This field is optional for reversing an authorization or credit.  #### DCC for First Data Your local currency. For details, see the `currency` field description in [Dynamic Currency Conversion For First Data Using the SCMP API](http://apps.cybersource.com/library/documentation/dev_guides/DCC_FirstData_SCMP/DCC_FirstData_SCMP_API.pdf).  #### Tax Calculation Required for international tax and value added tax only. Optional for U.S. and Canadian taxes. Your local currency. 

        :param currency: The currency of this PtsV2PaymentsRefundPost201ResponseRefundAmountDetails.
        :type: str
        """
        if currency is not None and len(currency) > 3:
            raise ValueError("Invalid value for `currency`, length must be less than or equal to `3`")

        self._currency = currency

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, PtsV2PaymentsRefundPost201ResponseRefundAmountDetails):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class TssV2TransactionsGet200ResponseConsumerAuthenticationInformation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'eci_raw': 'str',
        'cavv': 'str',
        'xid': 'str',
        'transaction_id': 'str'
    }

    attribute_map = {
        'eci_raw': 'eciRaw',
        'cavv': 'cavv',
        'xid': 'xid',
        'transaction_id': 'transactionId'
    }

    def __init__(self, eci_raw=None, cavv=None, xid=None, transaction_id=None):
        """
        TssV2TransactionsGet200ResponseConsumerAuthenticationInformation - a model defined in Swagger
        """

        self._eci_raw = None
        self._cavv = None
        self._xid = None
        self._transaction_id = None

        if eci_raw is not None:
          self.eci_raw = eci_raw
        if cavv is not None:
          self.cavv = cavv
        if xid is not None:
          self.xid = xid
        if transaction_id is not None:
          self.transaction_id = transaction_id

    @property
    def eci_raw(self):
        """
        Gets the eci_raw of this TssV2TransactionsGet200ResponseConsumerAuthenticationInformation.
        Raw electronic commerce indicator (ECI).  For details, see `eci_raw` request field description in [Credit Card Services Using the SCMP API.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/) 

        :return: The eci_raw of this TssV2TransactionsGet200ResponseConsumerAuthenticationInformation.
        :rtype: str
        """
        return self._eci_raw

    @eci_raw.setter
    def eci_raw(self, eci_raw):
        """
        Sets the eci_raw of this TssV2TransactionsGet200ResponseConsumerAuthenticationInformation.
        Raw electronic commerce indicator (ECI).  For details, see `eci_raw` request field description in [Credit Card Services Using the SCMP API.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/) 

        :param eci_raw: The eci_raw of this TssV2TransactionsGet200ResponseConsumerAuthenticationInformation.
        :type: str
        """
        if eci_raw is not None and len(eci_raw) > 2:
            raise ValueError("Invalid value for `eci_raw`, length must be less than or equal to `2`")

        self._eci_raw = eci_raw

    @property
    def cavv(self):
        """
        Gets the cavv of this TssV2TransactionsGet200ResponseConsumerAuthenticationInformation.
        Cardholder authentication verification value (CAVV).

        :return: The cavv of this TssV2TransactionsGet200ResponseConsumerAuthenticationInformation.
        :rtype: str
        """
        return self._cavv

    @cavv.setter
    def cavv(self, cavv):
        """
        Sets the cavv of this TssV2TransactionsGet200ResponseConsumerAuthenticationInformation.
        Cardholder authentication verification value (CAVV).

        :param cavv: The cavv of this TssV2TransactionsGet200ResponseConsumerAuthenticationInformation.
        :type: str
        """
        if cavv is not None and len(cavv) > 40:
            raise ValueError("Invalid value for `cavv`, length must be less than or equal to `40`")

        self._cavv = cavv

    @property
    def xid(self):
        """
        Gets the xid of this TssV2TransactionsGet200ResponseConsumerAuthenticationInformation.
        Transaction identifier.  For details, see `xid` request field description in [Credit Card Services Using the SCMP API.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/) 

        :return: The xid of this TssV2TransactionsGet200ResponseConsumerAuthenticationInformation.
        :rtype: str
        """
        return self._xid

    @xid.setter
    def xid(self, xid):
        """
        Sets the xid of this TssV2TransactionsGet200ResponseConsumerAuthenticationInformation.
        Transaction identifier.  For details, see `xid` request field description in [Credit Card Services Using the SCMP API.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/) 

        :param xid: The xid of this TssV2TransactionsGet200ResponseConsumerAuthenticationInformation.
        :type: str
        """
        if xid is not None and len(xid) > 40:
            raise ValueError("Invalid value for `xid`, length must be less than or equal to `40`")

        self._xid = xid

    @property
    def transaction_id(self):
        """
        Gets the transaction_id of this TssV2TransactionsGet200ResponseConsumerAuthenticationInformation.
        Payer auth Transaction identifier.

        :return: The transaction_id of this TssV2TransactionsGet200ResponseConsumerAuthenticationInformation.
        :rtype: str
        """
        return self._transaction_id

    @transaction_id.setter
    def transaction_id(self, transaction_id):
        """
        Sets the transaction_id of this TssV2TransactionsGet200ResponseConsumerAuthenticationInformation.
        Payer auth Transaction identifier.

        :param transaction_id: The transaction_id of this TssV2TransactionsGet200ResponseConsumerAuthenticationInformation.
        :type: str
        """

        self._transaction_id = transaction_id

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, TssV2TransactionsGet200ResponseConsumerAuthenticationInformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Vasv2taxClientReferenceInformationPartner(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'developer_id': 'str',
        'solution_id': 'str'
    }

    attribute_map = {
        'developer_id': 'developerId',
        'solution_id': 'solutionId'
    }

    def __init__(self, developer_id=None, solution_id=None):
        """
        Vasv2taxClientReferenceInformationPartner - a model defined in Swagger
        """

        self._developer_id = None
        self._solution_id = None

        if developer_id is not None:
          self.developer_id = developer_id
        if solution_id is not None:
          self.solution_id = solution_id

    @property
    def developer_id(self):
        """
        Gets the developer_id of this Vasv2taxClientReferenceInformationPartner.
        Identifier for the developer that helped integrate a partner solution to CyberSource.  Send this value in all requests that are sent through the partner solutions built by that developer. CyberSource assigns the ID to the developer.  **Note** When you see a developer ID of 999 in reports, the developer ID that was submitted is incorrect. 

        :return: The developer_id of this Vasv2taxClientReferenceInformationPartner.
        :rtype: str
        """
        return self._developer_id

    @developer_id.setter
    def developer_id(self, developer_id):
        """
        Sets the developer_id of this Vasv2taxClientReferenceInformationPartner.
        Identifier for the developer that helped integrate a partner solution to CyberSource.  Send this value in all requests that are sent through the partner solutions built by that developer. CyberSource assigns the ID to the developer.  **Note** When you see a developer ID of 999 in reports, the developer ID that was submitted is incorrect. 

        :param developer_id: The developer_id of this Vasv2taxClientReferenceInformationPartner.
        :type: str
        """
        if developer_id is not None and len(developer_id) > 8:
            raise ValueError("Invalid value for `developer_id`, length must be less than or equal to `8`")

        self._developer_id = developer_id

    @property
    def solution_id(self):
        """
        Gets the solution_id of this Vasv2taxClientReferenceInformationPartner.
        Identifier for the partner that is integrated to CyberSource.  Send this value in all requests that are sent through the partner solution. CyberSource assigns the ID to the partner.  **Note** When you see a solutionId of 999 in reports, the solutionId that was submitted is incorrect. 

        :return: The solution_id of this Vasv2taxClientReferenceInformationPartner.
        :rtype: str
        """
        return self._solution_id

    @solution_id.setter
    def solution_id(self, solution_id):
        """
        Sets the solution_id of this Vasv2taxClientReferenceInformationPartner.
        Identifier for the partner that is integrated to CyberSource.  Send this value in all requests that are sent through the partner solution. CyberSource assigns the ID to the partner.  **Note** When you see a solutionId of 999 in reports, the solutionId that was submitted is incorrect. 

        :param solution_id: The solution_id of this Vasv2taxClientReferenceInformationPartner.
        :type: str
        """
        if solution_id is not None and len(solution_id) > 8:
            raise ValueError("Invalid value for `solution_id`, length must be less than or equal to `8`")

        self._solution_id = solution_id

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Vasv2taxClientReferenceInformationPartner):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class RiskV1AuthenticationSetupsPost201ResponseConsumerAuthenticationInformation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'access_token': 'str',
        'reference_id': 'str',
        'device_data_collection_url': 'str'
    }

    attribute_map = {
        'access_token': 'accessToken',
        'reference_id': 'referenceId',
        'device_data_collection_url': 'deviceDataCollectionUrl'
    }

    def __init__(self, access_token=None, reference_id=None, device_data_collection_url=None):
        """
        RiskV1AuthenticationSetupsPost201ResponseConsumerAuthenticationInformation - a model defined in Swagger
        """

        self._access_token = None
        self._reference_id = None
        self._device_data_collection_url = None

        if access_token is not None:
          self.access_token = access_token
        if reference_id is not None:
          self.reference_id = reference_id
        if device_data_collection_url is not None:
          self.device_data_collection_url = device_data_collection_url

    @property
    def access_token(self):
        """
        Gets the access_token of this RiskV1AuthenticationSetupsPost201ResponseConsumerAuthenticationInformation.
        JSON Web Token (JWT) used to authenticate the consumer with the authentication provider, such as, CardinalCommerce or Rupay. 

        :return: The access_token of this RiskV1AuthenticationSetupsPost201ResponseConsumerAuthenticationInformation.
        :rtype: str
        """
        return self._access_token

    @access_token.setter
    def access_token(self, access_token):
        """
        Sets the access_token of this RiskV1AuthenticationSetupsPost201ResponseConsumerAuthenticationInformation.
        JSON Web Token (JWT) used to authenticate the consumer with the authentication provider, such as, CardinalCommerce or Rupay. 

        :param access_token: The access_token of this RiskV1AuthenticationSetupsPost201ResponseConsumerAuthenticationInformation.
        :type: str
        """
        if access_token is not None and len(access_token) > 2048:
            raise ValueError("Invalid value for `access_token`, length must be less than or equal to `2048`")

        self._access_token = access_token

    @property
    def reference_id(self):
        """
        Gets the reference_id of this RiskV1AuthenticationSetupsPost201ResponseConsumerAuthenticationInformation.
        This identifier represents cardinal has started device data collection session and this must be passed in Authentication JWT to Cardinal when invoking the deviceDataCollectionUrl. 

        :return: The reference_id of this RiskV1AuthenticationSetupsPost201ResponseConsumerAuthenticationInformation.
        :rtype: str
        """
        return self._reference_id

    @reference_id.setter
    def reference_id(self, reference_id):
        """
        Sets the reference_id of this RiskV1AuthenticationSetupsPost201ResponseConsumerAuthenticationInformation.
        This identifier represents cardinal has started device data collection session and this must be passed in Authentication JWT to Cardinal when invoking the deviceDataCollectionUrl. 

        :param reference_id: The reference_id of this RiskV1AuthenticationSetupsPost201ResponseConsumerAuthenticationInformation.
        :type: str
        """
        if reference_id is not None and len(reference_id) > 50:
            raise ValueError("Invalid value for `reference_id`, length must be less than or equal to `50`")

        self._reference_id = reference_id

    @property
    def device_data_collection_url(self):
        """
        Gets the device_data_collection_url of this RiskV1AuthenticationSetupsPost201ResponseConsumerAuthenticationInformation.
        The deviceDataCollectionUrl is the location to send the Authentication JWT when invoking the Device Data collection process. 

        :return: The device_data_collection_url of this RiskV1AuthenticationSetupsPost201ResponseConsumerAuthenticationInformation.
        :rtype: str
        """
        return self._device_data_collection_url

    @device_data_collection_url.setter
    def device_data_collection_url(self, device_data_collection_url):
        """
        Sets the device_data_collection_url of this RiskV1AuthenticationSetupsPost201ResponseConsumerAuthenticationInformation.
        The deviceDataCollectionUrl is the location to send the Authentication JWT when invoking the Device Data collection process. 

        :param device_data_collection_url: The device_data_collection_url of this RiskV1AuthenticationSetupsPost201ResponseConsumerAuthenticationInformation.
        :type: str
        """
        if device_data_collection_url is not None and len(device_data_collection_url) > 100:
            raise ValueError("Invalid value for `device_data_collection_url`, length must be less than or equal to `100`")

        self._device_data_collection_url = device_data_collection_url

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, RiskV1AuthenticationSetupsPost201ResponseConsumerAuthenticationInformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class TokenizeParameters(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'key_id': 'str',
        'card_info': 'TokenizeParametersCardInfo'
    }

    attribute_map = {
        'key_id': 'keyId',
        'card_info': 'cardInfo'
    }

    def __init__(self, key_id=None, card_info=None):
        """
        TokenizeParameters - a model defined in Swagger
        """

        self._key_id = None
        self._card_info = None

        self.key_id = key_id
        if card_info is not None:
          self.card_info = card_info

    @property
    def key_id(self):
        """
        Gets the key_id of this TokenizeParameters.
        Unique identifier for the generated token. This is obtained from the Generate Key request. See the [Java Script and Java examples](http://apps.cybersource.com/library/documentation/dev_guides/Secure_Acceptance_Flex/Key/html) on how to import the key and encrypt using the imported key.

        :return: The key_id of this TokenizeParameters.
        :rtype: str
        """
        return self._key_id

    @key_id.setter
    def key_id(self, key_id):
        """
        Sets the key_id of this TokenizeParameters.
        Unique identifier for the generated token. This is obtained from the Generate Key request. See the [Java Script and Java examples](http://apps.cybersource.com/library/documentation/dev_guides/Secure_Acceptance_Flex/Key/html) on how to import the key and encrypt using the imported key.

        :param key_id: The key_id of this TokenizeParameters.
        :type: str
        """
        if key_id is None:
            raise ValueError("Invalid value for `key_id`, must not be `None`")

        self._key_id = key_id

    @property
    def card_info(self):
        """
        Gets the card_info of this TokenizeParameters.

        :return: The card_info of this TokenizeParameters.
        :rtype: TokenizeParametersCardInfo
        """
        return self._card_info

    @card_info.setter
    def card_info(self, card_info):
        """
        Sets the card_info of this TokenizeParameters.

        :param card_info: The card_info of this TokenizeParameters.
        :type: TokenizeParametersCardInfo
        """

        self._card_info = card_info

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, TokenizeParameters):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Riskv1authenticationsetupsTokenInformation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'transient_token': 'str'
    }

    attribute_map = {
        'transient_token': 'transientToken'
    }

    def __init__(self, transient_token=None):
        """
        Riskv1authenticationsetupsTokenInformation - a model defined in Swagger
        """

        self._transient_token = None

        if transient_token is not None:
          self.transient_token = transient_token

    @property
    def transient_token(self):
        """
        Gets the transient_token of this Riskv1authenticationsetupsTokenInformation.
        A temporary ID that represents the customer's payment data (which is securely stored in Visa Data Centers). Flex Microform generates this ID and sets it to expire within 15 minutes from when the ID is generated or until the first payment authorization is carried out (whichever occurs first).  Valid value for the ID is a 64-character, alphanumeric string.  Example: 1D08M4YB968R1F7YVL4TBBKYVNRIR02VZFH9CBYSQIJJXORPI1NK5C98D7F6EB53 

        :return: The transient_token of this Riskv1authenticationsetupsTokenInformation.
        :rtype: str
        """
        return self._transient_token

    @transient_token.setter
    def transient_token(self, transient_token):
        """
        Sets the transient_token of this Riskv1authenticationsetupsTokenInformation.
        A temporary ID that represents the customer's payment data (which is securely stored in Visa Data Centers). Flex Microform generates this ID and sets it to expire within 15 minutes from when the ID is generated or until the first payment authorization is carried out (whichever occurs first).  Valid value for the ID is a 64-character, alphanumeric string.  Example: 1D08M4YB968R1F7YVL4TBBKYVNRIR02VZFH9CBYSQIJJXORPI1NK5C98D7F6EB53 

        :param transient_token: The transient_token of this Riskv1authenticationsetupsTokenInformation.
        :type: str
        """

        self._transient_token = transient_token

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Riskv1authenticationsetupsTokenInformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Ptsv2payoutsProcessingInformation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'business_application_id': 'str',
        'network_routing_order': 'str',
        'commerce_indicator': 'str',
        'reconciliation_id': 'str',
        'payouts_options': 'Ptsv2payoutsProcessingInformationPayoutsOptions'
    }

    attribute_map = {
        'business_application_id': 'businessApplicationId',
        'network_routing_order': 'networkRoutingOrder',
        'commerce_indicator': 'commerceIndicator',
        'reconciliation_id': 'reconciliationId',
        'payouts_options': 'payoutsOptions'
    }

    def __init__(self, business_application_id=None, network_routing_order=None, commerce_indicator=None, reconciliation_id=None, payouts_options=None):
        """
        Ptsv2payoutsProcessingInformation - a model defined in Swagger
        """

        self._business_application_id = None
        self._network_routing_order = None
        self._commerce_indicator = None
        self._reconciliation_id = None
        self._payouts_options = None

        if business_application_id is not None:
          self.business_application_id = business_application_id
        if network_routing_order is not None:
          self.network_routing_order = network_routing_order
        if commerce_indicator is not None:
          self.commerce_indicator = commerce_indicator
        if reconciliation_id is not None:
          self.reconciliation_id = reconciliation_id
        if payouts_options is not None:
          self.payouts_options = payouts_options

    @property
    def business_application_id(self):
        """
        Gets the business_application_id of this Ptsv2payoutsProcessingInformation.
        Payouts transaction type.  Applicable Processors: FDC Compass, Paymentech, CtV  Possible values:  **Credit Card Bill Payment**   - **CP**: credit card bill payment  **Funds Disbursement**   - **FD**: funds disbursement  - **GD**: government disbursement  - **MD**: merchant disbursement  **Money Transfer**   - **AA**: account to account. Sender and receiver are same person.  - **PP**: person to person. Sender and receiver are different.  **Prepaid Load**   - **TU**: top up 

        :return: The business_application_id of this Ptsv2payoutsProcessingInformation.
        :rtype: str
        """
        return self._business_application_id

    @business_application_id.setter
    def business_application_id(self, business_application_id):
        """
        Sets the business_application_id of this Ptsv2payoutsProcessingInformation.
        Payouts transaction type.  Applicable Processors: FDC Compass, Paymentech, CtV  Possible values:  **Credit Card Bill Payment**   - **CP**: credit card bill payment  **Funds Disbursement**   - **FD**: funds disbursement  - **GD**: government disbursement  - **MD**: merchant disbursement  **Money Transfer**   - **AA**: account to account. Sender and receiver are same person.  - **PP**: person to person. Sender and receiver are different.  **Prepaid Load**   - **TU**: top up 

        :param business_application_id: The business_application_id of this Ptsv2payoutsProcessingInformation.
        :type: str
        """
        if business_application_id is not None and len(business_application_id) > 2:
            raise ValueError("Invalid value for `business_application_id`, length must be less than or equal to `2`")

        self._business_application_id = business_application_id

    @property
    def network_routing_order(self):
        """
        Gets the network_routing_order of this Ptsv2payoutsProcessingInformation.
        This field is optionally used by Push Payments Gateway participants (merchants and acquirers) to get the attributes for specified networks only. The networks specified in this field must be a subset of the information provided during program enrollment. Refer to Sharing Group Code/Network Routing Order. Note: Supported only in US for domestic transactions involving Push Payments Gateway Service.  VisaNet checks to determine if there are issuer routing preferences for any of the networks specified by the network routing order. If an issuer preference exists for one of the specified debit networks, VisaNet makes a routing selection based on the issuer’s preference.  If an issuer preference exists for more than one of the specified debit networks, or if no issuer preference exists, VisaNet makes a selection based on the acquirer’s routing priorities.   For details, see the `network_order` field description in [BIN Lookup Service Using the SCMP API.](http://apps.cybersource.com/library/documentation/BIN_Lookup/BIN_Lookup_SCMP_API/html/) 

        :return: The network_routing_order of this Ptsv2payoutsProcessingInformation.
        :rtype: str
        """
        return self._network_routing_order

    @network_routing_order.setter
    def network_routing_order(self, network_routing_order):
        """
        Sets the network_routing_order of this Ptsv2payoutsProcessingInformation.
        This field is optionally used by Push Payments Gateway participants (merchants and acquirers) to get the attributes for specified networks only. The networks specified in this field must be a subset of the information provided during program enrollment. Refer to Sharing Group Code/Network Routing Order. Note: Supported only in US for domestic transactions involving Push Payments Gateway Service.  VisaNet checks to determine if there are issuer routing preferences for any of the networks specified by the network routing order. If an issuer preference exists for one of the specified debit networks, VisaNet makes a routing selection based on the issuer’s preference.  If an issuer preference exists for more than one of the specified debit networks, or if no issuer preference exists, VisaNet makes a selection based on the acquirer’s routing priorities.   For details, see the `network_order` field description in [BIN Lookup Service Using the SCMP API.](http://apps.cybersource.com/library/documentation/BIN_Lookup/BIN_Lookup_SCMP_API/html/) 

        :param network_routing_order: The network_routing_order of this Ptsv2payoutsProcessingInformation.
        :type: str
        """
        if network_routing_order is not None and len(network_routing_order) > 30:
            raise ValueError("Invalid value for `network_routing_order`, length must be less than or equal to `30`")

        self._network_routing_order = network_routing_order

    @property
    def commerce_indicator(self):
        """
        Gets the commerce_indicator of this Ptsv2payoutsProcessingInformation.
        Type of transaction.  Value for an OCT transaction: - `internet`  For details, see the `e_commerce_indicator` field description in [Payouts Using the SCMP API.](http://apps.cybersource.com/library/documentation/dev_guides/payouts_SCMP/html/) 

        :return: The commerce_indicator of this Ptsv2payoutsProcessingInformation.
        :rtype: str
        """
        return self._commerce_indicator

    @commerce_indicator.setter
    def commerce_indicator(self, commerce_indicator):
        """
        Sets the commerce_indicator of this Ptsv2payoutsProcessingInformation.
        Type of transaction.  Value for an OCT transaction: - `internet`  For details, see the `e_commerce_indicator` field description in [Payouts Using the SCMP API.](http://apps.cybersource.com/library/documentation/dev_guides/payouts_SCMP/html/) 

        :param commerce_indicator: The commerce_indicator of this Ptsv2payoutsProcessingInformation.
        :type: str
        """
        if commerce_indicator is not None and len(commerce_indicator) > 13:
            raise ValueError("Invalid value for `commerce_indicator`, length must be less than or equal to `13`")

        self._commerce_indicator = commerce_indicator

    @property
    def reconciliation_id(self):
        """
        Gets the reconciliation_id of this Ptsv2payoutsProcessingInformation.
        Please check with Cybersource customer support to see if your merchant account is configured correctly so you can include this field in your request. * For Payouts: max length for FDCCompass is String (22). 

        :return: The reconciliation_id of this Ptsv2payoutsProcessingInformation.
        :rtype: str
        """
        return self._reconciliation_id

    @reconciliation_id.setter
    def reconciliation_id(self, reconciliation_id):
        """
        Sets the reconciliation_id of this Ptsv2payoutsProcessingInformation.
        Please check with Cybersource customer support to see if your merchant account is configured correctly so you can include this field in your request. * For Payouts: max length for FDCCompass is String (22). 

        :param reconciliation_id: The reconciliation_id of this Ptsv2payoutsProcessingInformation.
        :type: str
        """
        if reconciliation_id is not None and len(reconciliation_id) > 60:
            raise ValueError("Invalid value for `reconciliation_id`, length must be less than or equal to `60`")

        self._reconciliation_id = reconciliation_id

    @property
    def payouts_options(self):
        """
        Gets the payouts_options of this Ptsv2payoutsProcessingInformation.

        :return: The payouts_options of this Ptsv2payoutsProcessingInformation.
        :rtype: Ptsv2payoutsProcessingInformationPayoutsOptions
        """
        return self._payouts_options

    @payouts_options.setter
    def payouts_options(self, payouts_options):
        """
        Sets the payouts_options of this Ptsv2payoutsProcessingInformation.

        :param payouts_options: The payouts_options of this Ptsv2payoutsProcessingInformation.
        :type: Ptsv2payoutsProcessingInformationPayoutsOptions
        """

        self._payouts_options = payouts_options

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Ptsv2payoutsProcessingInformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Ptsv2paymentsTravelInformationAutoRentalRentalAddress(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'city': 'str',
        'state': 'str',
        'country': 'str',
        'location_id': 'str',
        'address1': 'str',
        'address2': 'str',
        'location': 'str'
    }

    attribute_map = {
        'city': 'city',
        'state': 'state',
        'country': 'country',
        'location_id': 'locationId',
        'address1': 'address1',
        'address2': 'address2',
        'location': 'location'
    }

    def __init__(self, city=None, state=None, country=None, location_id=None, address1=None, address2=None, location=None):
        """
        Ptsv2paymentsTravelInformationAutoRentalRentalAddress - a model defined in Swagger
        """

        self._city = None
        self._state = None
        self._country = None
        self._location_id = None
        self._address1 = None
        self._address2 = None
        self._location = None

        if city is not None:
          self.city = city
        if state is not None:
          self.state = state
        if country is not None:
          self.country = country
        if location_id is not None:
          self.location_id = location_id
        if address1 is not None:
          self.address1 = address1
        if address2 is not None:
          self.address2 = address2
        if location is not None:
          self.location = location

    @property
    def city(self):
        """
        Gets the city of this Ptsv2paymentsTravelInformationAutoRentalRentalAddress.
        City in which the auto was rented.  For authorizations, this field is supported for Visa, MasterCard, and American Express.  For captures, this field is supported only for American Express.  For all other card types, this field is ignored. 

        :return: The city of this Ptsv2paymentsTravelInformationAutoRentalRentalAddress.
        :rtype: str
        """
        return self._city

    @city.setter
    def city(self, city):
        """
        Sets the city of this Ptsv2paymentsTravelInformationAutoRentalRentalAddress.
        City in which the auto was rented.  For authorizations, this field is supported for Visa, MasterCard, and American Express.  For captures, this field is supported only for American Express.  For all other card types, this field is ignored. 

        :param city: The city of this Ptsv2paymentsTravelInformationAutoRentalRentalAddress.
        :type: str
        """
        if city is not None and len(city) > 25:
            raise ValueError("Invalid value for `city`, length must be less than or equal to `25`")

        self._city = city

    @property
    def state(self):
        """
        Gets the state of this Ptsv2paymentsTravelInformationAutoRentalRentalAddress.
        State in which the auto was rented. Use the [State, Province, and Territory Codes for the United States and Canada](https://developer.cybersource.com/library/documentation/sbc/quickref/states_and_provinces.pdf). 

        :return: The state of this Ptsv2paymentsTravelInformationAutoRentalRentalAddress.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this Ptsv2paymentsTravelInformationAutoRentalRentalAddress.
        State in which the auto was rented. Use the [State, Province, and Territory Codes for the United States and Canada](https://developer.cybersource.com/library/documentation/sbc/quickref/states_and_provinces.pdf). 

        :param state: The state of this Ptsv2paymentsTravelInformationAutoRentalRentalAddress.
        :type: str
        """
        if state is not None and len(state) > 3:
            raise ValueError("Invalid value for `state`, length must be less than or equal to `3`")

        self._state = state

    @property
    def country(self):
        """
        Gets the country of this Ptsv2paymentsTravelInformationAutoRentalRentalAddress.
        Country where the auto was rented. Use the [ISO Standard Country Codes.](https://developer.cybersource.com/library/documentation/sbc/quickref/countries_alpha_list.pdf) This field is supported only for American Express. 

        :return: The country of this Ptsv2paymentsTravelInformationAutoRentalRentalAddress.
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """
        Sets the country of this Ptsv2paymentsTravelInformationAutoRentalRentalAddress.
        Country where the auto was rented. Use the [ISO Standard Country Codes.](https://developer.cybersource.com/library/documentation/sbc/quickref/countries_alpha_list.pdf) This field is supported only for American Express. 

        :param country: The country of this Ptsv2paymentsTravelInformationAutoRentalRentalAddress.
        :type: str
        """
        if country is not None and len(country) > 3:
            raise ValueError("Invalid value for `country`, length must be less than or equal to `3`")

        self._country = country

    @property
    def location_id(self):
        """
        Gets the location_id of this Ptsv2paymentsTravelInformationAutoRentalRentalAddress.
        The agency code, address, phone number, etc., used to identify the location where the vehicle was rented. 

        :return: The location_id of this Ptsv2paymentsTravelInformationAutoRentalRentalAddress.
        :rtype: str
        """
        return self._location_id

    @location_id.setter
    def location_id(self, location_id):
        """
        Sets the location_id of this Ptsv2paymentsTravelInformationAutoRentalRentalAddress.
        The agency code, address, phone number, etc., used to identify the location where the vehicle was rented. 

        :param location_id: The location_id of this Ptsv2paymentsTravelInformationAutoRentalRentalAddress.
        :type: str
        """
        if location_id is not None and len(location_id) > 10:
            raise ValueError("Invalid value for `location_id`, length must be less than or equal to `10`")

        self._location_id = location_id

    @property
    def address1(self):
        """
        Gets the address1 of this Ptsv2paymentsTravelInformationAutoRentalRentalAddress.
        Address from where the vehicle was rented. 

        :return: The address1 of this Ptsv2paymentsTravelInformationAutoRentalRentalAddress.
        :rtype: str
        """
        return self._address1

    @address1.setter
    def address1(self, address1):
        """
        Sets the address1 of this Ptsv2paymentsTravelInformationAutoRentalRentalAddress.
        Address from where the vehicle was rented. 

        :param address1: The address1 of this Ptsv2paymentsTravelInformationAutoRentalRentalAddress.
        :type: str
        """
        if address1 is not None and len(address1) > 13:
            raise ValueError("Invalid value for `address1`, length must be less than or equal to `13`")

        self._address1 = address1

    @property
    def address2(self):
        """
        Gets the address2 of this Ptsv2paymentsTravelInformationAutoRentalRentalAddress.
        Address from where the vehicle was rented. 

        :return: The address2 of this Ptsv2paymentsTravelInformationAutoRentalRentalAddress.
        :rtype: str
        """
        return self._address2

    @address2.setter
    def address2(self, address2):
        """
        Sets the address2 of this Ptsv2paymentsTravelInformationAutoRentalRentalAddress.
        Address from where the vehicle was rented. 

        :param address2: The address2 of this Ptsv2paymentsTravelInformationAutoRentalRentalAddress.
        :type: str
        """
        if address2 is not None and len(address2) > 13:
            raise ValueError("Invalid value for `address2`, length must be less than or equal to `13`")

        self._address2 = address2

    @property
    def location(self):
        """
        Gets the location of this Ptsv2paymentsTravelInformationAutoRentalRentalAddress.
        This field contains the location where a taxi passenger was picked up or where an auto rental vehicle was picked up. In most cases, this is the rental agency's business name that appears on the storefront and/or customer receipts, commonly referred to as the DBA (Doing Business As) name. However, if the vehicle was picked up at another location (e.g., a hotel,auto dealership, repair shop, etc.), the name of that location should be used. This entry must be easily recognized by the Cardmember to avoid unnecessary inquiries. If the name is more than 38  characters, use proper and meaningful abbreviation, when possible. 

        :return: The location of this Ptsv2paymentsTravelInformationAutoRentalRentalAddress.
        :rtype: str
        """
        return self._location

    @location.setter
    def location(self, location):
        """
        Sets the location of this Ptsv2paymentsTravelInformationAutoRentalRentalAddress.
        This field contains the location where a taxi passenger was picked up or where an auto rental vehicle was picked up. In most cases, this is the rental agency's business name that appears on the storefront and/or customer receipts, commonly referred to as the DBA (Doing Business As) name. However, if the vehicle was picked up at another location (e.g., a hotel,auto dealership, repair shop, etc.), the name of that location should be used. This entry must be easily recognized by the Cardmember to avoid unnecessary inquiries. If the name is more than 38  characters, use proper and meaningful abbreviation, when possible. 

        :param location: The location of this Ptsv2paymentsTravelInformationAutoRentalRentalAddress.
        :type: str
        """
        if location is not None and len(location) > 38:
            raise ValueError("Invalid value for `location`, length must be less than or equal to `38`")

        self._location = location

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Ptsv2paymentsTravelInformationAutoRentalRentalAddress):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Ptsv2paymentsProcessingInformationJapanPaymentOptions(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'payment_method': 'str',
        'installments': 'str',
        'terminal_id': 'str',
        'first_billing_month': 'str',
        'business_name': 'str',
        'business_name_katakana': 'str',
        'jis2_track_data': 'str',
        'business_name_alpha_numeric': 'str'
    }

    attribute_map = {
        'payment_method': 'paymentMethod',
        'installments': 'installments',
        'terminal_id': 'terminalId',
        'first_billing_month': 'firstBillingMonth',
        'business_name': 'businessName',
        'business_name_katakana': 'businessNameKatakana',
        'jis2_track_data': 'jis2TrackData',
        'business_name_alpha_numeric': 'businessNameAlphaNumeric'
    }

    def __init__(self, payment_method=None, installments=None, terminal_id=None, first_billing_month=None, business_name=None, business_name_katakana=None, jis2_track_data=None, business_name_alpha_numeric=None):
        """
        Ptsv2paymentsProcessingInformationJapanPaymentOptions - a model defined in Swagger
        """

        self._payment_method = None
        self._installments = None
        self._terminal_id = None
        self._first_billing_month = None
        self._business_name = None
        self._business_name_katakana = None
        self._jis2_track_data = None
        self._business_name_alpha_numeric = None

        if payment_method is not None:
          self.payment_method = payment_method
        if installments is not None:
          self.installments = installments
        if terminal_id is not None:
          self.terminal_id = terminal_id
        if first_billing_month is not None:
          self.first_billing_month = first_billing_month
        if business_name is not None:
          self.business_name = business_name
        if business_name_katakana is not None:
          self.business_name_katakana = business_name_katakana
        if jis2_track_data is not None:
          self.jis2_track_data = jis2_track_data
        if business_name_alpha_numeric is not None:
          self.business_name_alpha_numeric = business_name_alpha_numeric

    @property
    def payment_method(self):
        """
        Gets the payment_method of this Ptsv2paymentsProcessingInformationJapanPaymentOptions.
        This value is a 2-digit code indicating the payment method. Use Payment Method Code value that applies to the tranasction. - 10 (One-time payment) - 21, 22, 23, 24  (Bonus(one-time)payment) - 61 (Installment payment) - 31, 32, 33, 34  (Integrated (Bonus + Installment)payment) - 80 (Revolving payment) 

        :return: The payment_method of this Ptsv2paymentsProcessingInformationJapanPaymentOptions.
        :rtype: str
        """
        return self._payment_method

    @payment_method.setter
    def payment_method(self, payment_method):
        """
        Sets the payment_method of this Ptsv2paymentsProcessingInformationJapanPaymentOptions.
        This value is a 2-digit code indicating the payment method. Use Payment Method Code value that applies to the tranasction. - 10 (One-time payment) - 21, 22, 23, 24  (Bonus(one-time)payment) - 61 (Installment payment) - 31, 32, 33, 34  (Integrated (Bonus + Installment)payment) - 80 (Revolving payment) 

        :param payment_method: The payment_method of this Ptsv2paymentsProcessingInformationJapanPaymentOptions.
        :type: str
        """
        if payment_method is not None and len(payment_method) > 2:
            raise ValueError("Invalid value for `payment_method`, length must be less than or equal to `2`")

        self._payment_method = payment_method

    @property
    def installments(self):
        """
        Gets the installments of this Ptsv2paymentsProcessingInformationJapanPaymentOptions.
        Number of Installments. 

        :return: The installments of this Ptsv2paymentsProcessingInformationJapanPaymentOptions.
        :rtype: str
        """
        return self._installments

    @installments.setter
    def installments(self, installments):
        """
        Sets the installments of this Ptsv2paymentsProcessingInformationJapanPaymentOptions.
        Number of Installments. 

        :param installments: The installments of this Ptsv2paymentsProcessingInformationJapanPaymentOptions.
        :type: str
        """

        self._installments = installments

    @property
    def terminal_id(self):
        """
        Gets the terminal_id of this Ptsv2paymentsProcessingInformationJapanPaymentOptions.
        Unique Japan Credit Card Association (JCCA) terminal identifier.  The difference between this field and the `pointOfSaleInformation.terminalID` field is that you can define `pointOfSaleInformation.terminalID`, but `processingInformation.japanPaymentOptions.terminalId` is defined by the JCCA and is used only in Japan.  This field is supported only on CyberSource through VisaNet and JCN Gateway.  Optional field. 

        :return: The terminal_id of this Ptsv2paymentsProcessingInformationJapanPaymentOptions.
        :rtype: str
        """
        return self._terminal_id

    @terminal_id.setter
    def terminal_id(self, terminal_id):
        """
        Sets the terminal_id of this Ptsv2paymentsProcessingInformationJapanPaymentOptions.
        Unique Japan Credit Card Association (JCCA) terminal identifier.  The difference between this field and the `pointOfSaleInformation.terminalID` field is that you can define `pointOfSaleInformation.terminalID`, but `processingInformation.japanPaymentOptions.terminalId` is defined by the JCCA and is used only in Japan.  This field is supported only on CyberSource through VisaNet and JCN Gateway.  Optional field. 

        :param terminal_id: The terminal_id of this Ptsv2paymentsProcessingInformationJapanPaymentOptions.
        :type: str
        """
        if terminal_id is not None and len(terminal_id) > 13:
            raise ValueError("Invalid value for `terminal_id`, length must be less than or equal to `13`")

        self._terminal_id = terminal_id

    @property
    def first_billing_month(self):
        """
        Gets the first_billing_month of this Ptsv2paymentsProcessingInformationJapanPaymentOptions.
        Billing month in MM format. 

        :return: The first_billing_month of this Ptsv2paymentsProcessingInformationJapanPaymentOptions.
        :rtype: str
        """
        return self._first_billing_month

    @first_billing_month.setter
    def first_billing_month(self, first_billing_month):
        """
        Sets the first_billing_month of this Ptsv2paymentsProcessingInformationJapanPaymentOptions.
        Billing month in MM format. 

        :param first_billing_month: The first_billing_month of this Ptsv2paymentsProcessingInformationJapanPaymentOptions.
        :type: str
        """
        if first_billing_month is not None and len(first_billing_month) > 2:
            raise ValueError("Invalid value for `first_billing_month`, length must be less than or equal to `2`")

        self._first_billing_month = first_billing_month

    @property
    def business_name(self):
        """
        Gets the business_name of this Ptsv2paymentsProcessingInformationJapanPaymentOptions.
        Business name in Japanese characters. This field is supported only on JCN Gateway and for the Sumitomo Mitsui Card Co. acquirer on CyberSource through VisaNet. 

        :return: The business_name of this Ptsv2paymentsProcessingInformationJapanPaymentOptions.
        :rtype: str
        """
        return self._business_name

    @business_name.setter
    def business_name(self, business_name):
        """
        Sets the business_name of this Ptsv2paymentsProcessingInformationJapanPaymentOptions.
        Business name in Japanese characters. This field is supported only on JCN Gateway and for the Sumitomo Mitsui Card Co. acquirer on CyberSource through VisaNet. 

        :param business_name: The business_name of this Ptsv2paymentsProcessingInformationJapanPaymentOptions.
        :type: str
        """
        if business_name is not None and len(business_name) > 25:
            raise ValueError("Invalid value for `business_name`, length must be less than or equal to `25`")

        self._business_name = business_name

    @property
    def business_name_katakana(self):
        """
        Gets the business_name_katakana of this Ptsv2paymentsProcessingInformationJapanPaymentOptions.
        Business name in Katakana characters. This field is supported only on JCN Gateway and for the Sumitomo Mitsui Card Co. acquirer on CyberSource through VisaNet. 

        :return: The business_name_katakana of this Ptsv2paymentsProcessingInformationJapanPaymentOptions.
        :rtype: str
        """
        return self._business_name_katakana

    @business_name_katakana.setter
    def business_name_katakana(self, business_name_katakana):
        """
        Sets the business_name_katakana of this Ptsv2paymentsProcessingInformationJapanPaymentOptions.
        Business name in Katakana characters. This field is supported only on JCN Gateway and for the Sumitomo Mitsui Card Co. acquirer on CyberSource through VisaNet. 

        :param business_name_katakana: The business_name_katakana of this Ptsv2paymentsProcessingInformationJapanPaymentOptions.
        :type: str
        """
        if business_name_katakana is not None and len(business_name_katakana) > 25:
            raise ValueError("Invalid value for `business_name_katakana`, length must be less than or equal to `25`")

        self._business_name_katakana = business_name_katakana

    @property
    def jis2_track_data(self):
        """
        Gets the jis2_track_data of this Ptsv2paymentsProcessingInformationJapanPaymentOptions.
        Japanese Industrial Standard Type 2 (JIS2) track data from the front of the card.  This field is supported only on CyberSource through VisaNet and JCN Gateway.  Optional field. 

        :return: The jis2_track_data of this Ptsv2paymentsProcessingInformationJapanPaymentOptions.
        :rtype: str
        """
        return self._jis2_track_data

    @jis2_track_data.setter
    def jis2_track_data(self, jis2_track_data):
        """
        Sets the jis2_track_data of this Ptsv2paymentsProcessingInformationJapanPaymentOptions.
        Japanese Industrial Standard Type 2 (JIS2) track data from the front of the card.  This field is supported only on CyberSource through VisaNet and JCN Gateway.  Optional field. 

        :param jis2_track_data: The jis2_track_data of this Ptsv2paymentsProcessingInformationJapanPaymentOptions.
        :type: str
        """
        if jis2_track_data is not None and len(jis2_track_data) > 69:
            raise ValueError("Invalid value for `jis2_track_data`, length must be less than or equal to `69`")

        self._jis2_track_data = jis2_track_data

    @property
    def business_name_alpha_numeric(self):
        """
        Gets the business_name_alpha_numeric of this Ptsv2paymentsProcessingInformationJapanPaymentOptions.
        Business name in alphanumeric characters. This field is supported only on JCN Gateway and for the Sumitomo Mitsui Card Co. acquirer on CyberSource through VisaNet. 

        :return: The business_name_alpha_numeric of this Ptsv2paymentsProcessingInformationJapanPaymentOptions.
        :rtype: str
        """
        return self._business_name_alpha_numeric

    @business_name_alpha_numeric.setter
    def business_name_alpha_numeric(self, business_name_alpha_numeric):
        """
        Sets the business_name_alpha_numeric of this Ptsv2paymentsProcessingInformationJapanPaymentOptions.
        Business name in alphanumeric characters. This field is supported only on JCN Gateway and for the Sumitomo Mitsui Card Co. acquirer on CyberSource through VisaNet. 

        :param business_name_alpha_numeric: The business_name_alpha_numeric of this Ptsv2paymentsProcessingInformationJapanPaymentOptions.
        :type: str
        """
        if business_name_alpha_numeric is not None and len(business_name_alpha_numeric) > 25:
            raise ValueError("Invalid value for `business_name_alpha_numeric`, length must be less than or equal to `25`")

        self._business_name_alpha_numeric = business_name_alpha_numeric

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Ptsv2paymentsProcessingInformationJapanPaymentOptions):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class ReportingV3PurchaseRefundDetailsGet200ResponseFeeAndFundingDetails(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'request_id': 'str',
        'interchange_per_item_fee': 'str',
        'interchange_description': 'str',
        'interchange_percentage': 'str',
        'interchange_percentage_amount': 'str',
        'discount_percentage': 'str',
        'discount_amount': 'str',
        'discount_per_item_fee': 'str',
        'total_fee': 'str',
        'fee_currency': 'str',
        'dues_assessments': 'str',
        'funding_amount': 'str',
        'funding_currency': 'str'
    }

    attribute_map = {
        'request_id': 'requestId',
        'interchange_per_item_fee': 'interchangePerItemFee',
        'interchange_description': 'interchangeDescription',
        'interchange_percentage': 'interchangePercentage',
        'interchange_percentage_amount': 'interchangePercentageAmount',
        'discount_percentage': 'discountPercentage',
        'discount_amount': 'discountAmount',
        'discount_per_item_fee': 'discountPerItemFee',
        'total_fee': 'totalFee',
        'fee_currency': 'feeCurrency',
        'dues_assessments': 'duesAssessments',
        'funding_amount': 'fundingAmount',
        'funding_currency': 'fundingCurrency'
    }

    def __init__(self, request_id=None, interchange_per_item_fee=None, interchange_description=None, interchange_percentage=None, interchange_percentage_amount=None, discount_percentage=None, discount_amount=None, discount_per_item_fee=None, total_fee=None, fee_currency=None, dues_assessments=None, funding_amount=None, funding_currency=None):
        """
        ReportingV3PurchaseRefundDetailsGet200ResponseFeeAndFundingDetails - a model defined in Swagger
        """

        self._request_id = None
        self._interchange_per_item_fee = None
        self._interchange_description = None
        self._interchange_percentage = None
        self._interchange_percentage_amount = None
        self._discount_percentage = None
        self._discount_amount = None
        self._discount_per_item_fee = None
        self._total_fee = None
        self._fee_currency = None
        self._dues_assessments = None
        self._funding_amount = None
        self._funding_currency = None

        if request_id is not None:
          self.request_id = request_id
        if interchange_per_item_fee is not None:
          self.interchange_per_item_fee = interchange_per_item_fee
        if interchange_description is not None:
          self.interchange_description = interchange_description
        if interchange_percentage is not None:
          self.interchange_percentage = interchange_percentage
        if interchange_percentage_amount is not None:
          self.interchange_percentage_amount = interchange_percentage_amount
        if discount_percentage is not None:
          self.discount_percentage = discount_percentage
        if discount_amount is not None:
          self.discount_amount = discount_amount
        if discount_per_item_fee is not None:
          self.discount_per_item_fee = discount_per_item_fee
        if total_fee is not None:
          self.total_fee = total_fee
        if fee_currency is not None:
          self.fee_currency = fee_currency
        if dues_assessments is not None:
          self.dues_assessments = dues_assessments
        if funding_amount is not None:
          self.funding_amount = funding_amount
        if funding_currency is not None:
          self.funding_currency = funding_currency

    @property
    def request_id(self):
        """
        Gets the request_id of this ReportingV3PurchaseRefundDetailsGet200ResponseFeeAndFundingDetails.
        An unique identification number assigned by CyberSource to identify the submitted request.

        :return: The request_id of this ReportingV3PurchaseRefundDetailsGet200ResponseFeeAndFundingDetails.
        :rtype: str
        """
        return self._request_id

    @request_id.setter
    def request_id(self, request_id):
        """
        Sets the request_id of this ReportingV3PurchaseRefundDetailsGet200ResponseFeeAndFundingDetails.
        An unique identification number assigned by CyberSource to identify the submitted request.

        :param request_id: The request_id of this ReportingV3PurchaseRefundDetailsGet200ResponseFeeAndFundingDetails.
        :type: str
        """
        if request_id is not None and len(request_id) > 26:
            raise ValueError("Invalid value for `request_id`, length must be less than or equal to `26`")

        self._request_id = request_id

    @property
    def interchange_per_item_fee(self):
        """
        Gets the interchange_per_item_fee of this ReportingV3PurchaseRefundDetailsGet200ResponseFeeAndFundingDetails.
        interchange Per Item Fee

        :return: The interchange_per_item_fee of this ReportingV3PurchaseRefundDetailsGet200ResponseFeeAndFundingDetails.
        :rtype: str
        """
        return self._interchange_per_item_fee

    @interchange_per_item_fee.setter
    def interchange_per_item_fee(self, interchange_per_item_fee):
        """
        Sets the interchange_per_item_fee of this ReportingV3PurchaseRefundDetailsGet200ResponseFeeAndFundingDetails.
        interchange Per Item Fee

        :param interchange_per_item_fee: The interchange_per_item_fee of this ReportingV3PurchaseRefundDetailsGet200ResponseFeeAndFundingDetails.
        :type: str
        """

        self._interchange_per_item_fee = interchange_per_item_fee

    @property
    def interchange_description(self):
        """
        Gets the interchange_description of this ReportingV3PurchaseRefundDetailsGet200ResponseFeeAndFundingDetails.
        interchange Description

        :return: The interchange_description of this ReportingV3PurchaseRefundDetailsGet200ResponseFeeAndFundingDetails.
        :rtype: str
        """
        return self._interchange_description

    @interchange_description.setter
    def interchange_description(self, interchange_description):
        """
        Sets the interchange_description of this ReportingV3PurchaseRefundDetailsGet200ResponseFeeAndFundingDetails.
        interchange Description

        :param interchange_description: The interchange_description of this ReportingV3PurchaseRefundDetailsGet200ResponseFeeAndFundingDetails.
        :type: str
        """

        self._interchange_description = interchange_description

    @property
    def interchange_percentage(self):
        """
        Gets the interchange_percentage of this ReportingV3PurchaseRefundDetailsGet200ResponseFeeAndFundingDetails.
        interchange Percentage

        :return: The interchange_percentage of this ReportingV3PurchaseRefundDetailsGet200ResponseFeeAndFundingDetails.
        :rtype: str
        """
        return self._interchange_percentage

    @interchange_percentage.setter
    def interchange_percentage(self, interchange_percentage):
        """
        Sets the interchange_percentage of this ReportingV3PurchaseRefundDetailsGet200ResponseFeeAndFundingDetails.
        interchange Percentage

        :param interchange_percentage: The interchange_percentage of this ReportingV3PurchaseRefundDetailsGet200ResponseFeeAndFundingDetails.
        :type: str
        """

        self._interchange_percentage = interchange_percentage

    @property
    def interchange_percentage_amount(self):
        """
        Gets the interchange_percentage_amount of this ReportingV3PurchaseRefundDetailsGet200ResponseFeeAndFundingDetails.
        interchange Percentage Amount

        :return: The interchange_percentage_amount of this ReportingV3PurchaseRefundDetailsGet200ResponseFeeAndFundingDetails.
        :rtype: str
        """
        return self._interchange_percentage_amount

    @interchange_percentage_amount.setter
    def interchange_percentage_amount(self, interchange_percentage_amount):
        """
        Sets the interchange_percentage_amount of this ReportingV3PurchaseRefundDetailsGet200ResponseFeeAndFundingDetails.
        interchange Percentage Amount

        :param interchange_percentage_amount: The interchange_percentage_amount of this ReportingV3PurchaseRefundDetailsGet200ResponseFeeAndFundingDetails.
        :type: str
        """

        self._interchange_percentage_amount = interchange_percentage_amount

    @property
    def discount_percentage(self):
        """
        Gets the discount_percentage of this ReportingV3PurchaseRefundDetailsGet200ResponseFeeAndFundingDetails.
        Discount Percentage

        :return: The discount_percentage of this ReportingV3PurchaseRefundDetailsGet200ResponseFeeAndFundingDetails.
        :rtype: str
        """
        return self._discount_percentage

    @discount_percentage.setter
    def discount_percentage(self, discount_percentage):
        """
        Sets the discount_percentage of this ReportingV3PurchaseRefundDetailsGet200ResponseFeeAndFundingDetails.
        Discount Percentage

        :param discount_percentage: The discount_percentage of this ReportingV3PurchaseRefundDetailsGet200ResponseFeeAndFundingDetails.
        :type: str
        """

        self._discount_percentage = discount_percentage

    @property
    def discount_amount(self):
        """
        Gets the discount_amount of this ReportingV3PurchaseRefundDetailsGet200ResponseFeeAndFundingDetails.
        Discount Amount

        :return: The discount_amount of this ReportingV3PurchaseRefundDetailsGet200ResponseFeeAndFundingDetails.
        :rtype: str
        """
        return self._discount_amount

    @discount_amount.setter
    def discount_amount(self, discount_amount):
        """
        Sets the discount_amount of this ReportingV3PurchaseRefundDetailsGet200ResponseFeeAndFundingDetails.
        Discount Amount

        :param discount_amount: The discount_amount of this ReportingV3PurchaseRefundDetailsGet200ResponseFeeAndFundingDetails.
        :type: str
        """

        self._discount_amount = discount_amount

    @property
    def discount_per_item_fee(self):
        """
        Gets the discount_per_item_fee of this ReportingV3PurchaseRefundDetailsGet200ResponseFeeAndFundingDetails.
        Discount Per Item Fee

        :return: The discount_per_item_fee of this ReportingV3PurchaseRefundDetailsGet200ResponseFeeAndFundingDetails.
        :rtype: str
        """
        return self._discount_per_item_fee

    @discount_per_item_fee.setter
    def discount_per_item_fee(self, discount_per_item_fee):
        """
        Sets the discount_per_item_fee of this ReportingV3PurchaseRefundDetailsGet200ResponseFeeAndFundingDetails.
        Discount Per Item Fee

        :param discount_per_item_fee: The discount_per_item_fee of this ReportingV3PurchaseRefundDetailsGet200ResponseFeeAndFundingDetails.
        :type: str
        """

        self._discount_per_item_fee = discount_per_item_fee

    @property
    def total_fee(self):
        """
        Gets the total_fee of this ReportingV3PurchaseRefundDetailsGet200ResponseFeeAndFundingDetails.
        Total Fee

        :return: The total_fee of this ReportingV3PurchaseRefundDetailsGet200ResponseFeeAndFundingDetails.
        :rtype: str
        """
        return self._total_fee

    @total_fee.setter
    def total_fee(self, total_fee):
        """
        Sets the total_fee of this ReportingV3PurchaseRefundDetailsGet200ResponseFeeAndFundingDetails.
        Total Fee

        :param total_fee: The total_fee of this ReportingV3PurchaseRefundDetailsGet200ResponseFeeAndFundingDetails.
        :type: str
        """

        self._total_fee = total_fee

    @property
    def fee_currency(self):
        """
        Gets the fee_currency of this ReportingV3PurchaseRefundDetailsGet200ResponseFeeAndFundingDetails.
        Fee Currency

        :return: The fee_currency of this ReportingV3PurchaseRefundDetailsGet200ResponseFeeAndFundingDetails.
        :rtype: str
        """
        return self._fee_currency

    @fee_currency.setter
    def fee_currency(self, fee_currency):
        """
        Sets the fee_currency of this ReportingV3PurchaseRefundDetailsGet200ResponseFeeAndFundingDetails.
        Fee Currency

        :param fee_currency: The fee_currency of this ReportingV3PurchaseRefundDetailsGet200ResponseFeeAndFundingDetails.
        :type: str
        """

        self._fee_currency = fee_currency

    @property
    def dues_assessments(self):
        """
        Gets the dues_assessments of this ReportingV3PurchaseRefundDetailsGet200ResponseFeeAndFundingDetails.
        Dues Assessments

        :return: The dues_assessments of this ReportingV3PurchaseRefundDetailsGet200ResponseFeeAndFundingDetails.
        :rtype: str
        """
        return self._dues_assessments

    @dues_assessments.setter
    def dues_assessments(self, dues_assessments):
        """
        Sets the dues_assessments of this ReportingV3PurchaseRefundDetailsGet200ResponseFeeAndFundingDetails.
        Dues Assessments

        :param dues_assessments: The dues_assessments of this ReportingV3PurchaseRefundDetailsGet200ResponseFeeAndFundingDetails.
        :type: str
        """

        self._dues_assessments = dues_assessments

    @property
    def funding_amount(self):
        """
        Gets the funding_amount of this ReportingV3PurchaseRefundDetailsGet200ResponseFeeAndFundingDetails.
        Funding Amount

        :return: The funding_amount of this ReportingV3PurchaseRefundDetailsGet200ResponseFeeAndFundingDetails.
        :rtype: str
        """
        return self._funding_amount

    @funding_amount.setter
    def funding_amount(self, funding_amount):
        """
        Sets the funding_amount of this ReportingV3PurchaseRefundDetailsGet200ResponseFeeAndFundingDetails.
        Funding Amount

        :param funding_amount: The funding_amount of this ReportingV3PurchaseRefundDetailsGet200ResponseFeeAndFundingDetails.
        :type: str
        """

        self._funding_amount = funding_amount

    @property
    def funding_currency(self):
        """
        Gets the funding_currency of this ReportingV3PurchaseRefundDetailsGet200ResponseFeeAndFundingDetails.
        Funding Currency (ISO 4217)

        :return: The funding_currency of this ReportingV3PurchaseRefundDetailsGet200ResponseFeeAndFundingDetails.
        :rtype: str
        """
        return self._funding_currency

    @funding_currency.setter
    def funding_currency(self, funding_currency):
        """
        Sets the funding_currency of this ReportingV3PurchaseRefundDetailsGet200ResponseFeeAndFundingDetails.
        Funding Currency (ISO 4217)

        :param funding_currency: The funding_currency of this ReportingV3PurchaseRefundDetailsGet200ResponseFeeAndFundingDetails.
        :type: str
        """

        self._funding_currency = funding_currency

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ReportingV3PurchaseRefundDetailsGet200ResponseFeeAndFundingDetails):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class FileDetail(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'file_id': 'str',
        'name': 'str',
        'created_time': 'datetime',
        'last_modified_time': 'datetime',
        'date': 'date',
        'mime_type': 'str',
        'size': 'int'
    }

    attribute_map = {
        'file_id': 'fileId',
        'name': 'name',
        'created_time': 'createdTime',
        'last_modified_time': 'lastModifiedTime',
        'date': 'date',
        'mime_type': 'mimeType',
        'size': 'size'
    }

    def __init__(self, file_id=None, name=None, created_time=None, last_modified_time=None, date=None, mime_type=None, size=None):
        """
        FileDetail - a model defined in Swagger
        """

        self._file_id = None
        self._name = None
        self._created_time = None
        self._last_modified_time = None
        self._date = None
        self._mime_type = None
        self._size = None

        if file_id is not None:
          self.file_id = file_id
        if name is not None:
          self.name = name
        if created_time is not None:
          self.created_time = created_time
        if last_modified_time is not None:
          self.last_modified_time = last_modified_time
        if date is not None:
          self.date = date
        if mime_type is not None:
          self.mime_type = mime_type
        if size is not None:
          self.size = size

    @property
    def file_id(self):
        """
        Gets the file_id of this FileDetail.
        Unique identifier of a file

        :return: The file_id of this FileDetail.
        :rtype: str
        """
        return self._file_id

    @file_id.setter
    def file_id(self, file_id):
        """
        Sets the file_id of this FileDetail.
        Unique identifier of a file

        :param file_id: The file_id of this FileDetail.
        :type: str
        """

        self._file_id = file_id

    @property
    def name(self):
        """
        Gets the name of this FileDetail.
        Name of the file

        :return: The name of this FileDetail.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this FileDetail.
        Name of the file

        :param name: The name of this FileDetail.
        :type: str
        """

        self._name = name

    @property
    def created_time(self):
        """
        Gets the created_time of this FileDetail.
        Date and time for the file in PST

        :return: The created_time of this FileDetail.
        :rtype: datetime
        """
        return self._created_time

    @created_time.setter
    def created_time(self, created_time):
        """
        Sets the created_time of this FileDetail.
        Date and time for the file in PST

        :param created_time: The created_time of this FileDetail.
        :type: datetime
        """

        self._created_time = created_time

    @property
    def last_modified_time(self):
        """
        Gets the last_modified_time of this FileDetail.
        Date and time for the file in PST

        :return: The last_modified_time of this FileDetail.
        :rtype: datetime
        """
        return self._last_modified_time

    @last_modified_time.setter
    def last_modified_time(self, last_modified_time):
        """
        Sets the last_modified_time of this FileDetail.
        Date and time for the file in PST

        :param last_modified_time: The last_modified_time of this FileDetail.
        :type: datetime
        """

        self._last_modified_time = last_modified_time

    @property
    def date(self):
        """
        Gets the date of this FileDetail.
        Date and time for the file in PST

        :return: The date of this FileDetail.
        :rtype: date
        """
        return self._date

    @date.setter
    def date(self, date):
        """
        Sets the date of this FileDetail.
        Date and time for the file in PST

        :param date: The date of this FileDetail.
        :type: date
        """

        self._date = date

    @property
    def mime_type(self):
        """
        Gets the mime_type of this FileDetail.
        'File extension'  Valid values: - 'application/xml' - 'text/csv' - 'application/pdf' - 'application/octet-stream' 

        :return: The mime_type of this FileDetail.
        :rtype: str
        """
        return self._mime_type

    @mime_type.setter
    def mime_type(self, mime_type):
        """
        Sets the mime_type of this FileDetail.
        'File extension'  Valid values: - 'application/xml' - 'text/csv' - 'application/pdf' - 'application/octet-stream' 

        :param mime_type: The mime_type of this FileDetail.
        :type: str
        """

        self._mime_type = mime_type

    @property
    def size(self):
        """
        Gets the size of this FileDetail.
        Size of the file in bytes

        :return: The size of this FileDetail.
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """
        Sets the size of this FileDetail.
        Size of the file in bytes

        :param size: The size of this FileDetail.
        :type: int
        """

        self._size = size

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, FileDetail):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Ptsv2paymentsHealthCareInformationAmountDetails(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'amount_type': 'str',
        'amount': 'str'
    }

    attribute_map = {
        'amount_type': 'amountType',
        'amount': 'amount'
    }

    def __init__(self, amount_type=None, amount=None):
        """
        Ptsv2paymentsHealthCareInformationAmountDetails - a model defined in Swagger
        """

        self._amount_type = None
        self._amount = None

        if amount_type is not None:
          self.amount_type = amount_type
        if amount is not None:
          self.amount = amount

    @property
    def amount_type(self):
        """
        Gets the amount_type of this Ptsv2paymentsHealthCareInformationAmountDetails.
        Total amount that has been spent on healthcare in a transaction. Valid Values for **Visa**: - `healthcare` - Total Amount Healthcare - `healthcare-transit` - Amount Transit - `vision` - Amount Vision/Optical - `prescription` - Amount Prescription/RX - `clinic` - Amount Clinic/Other Qualified Medical - `dental` - Amount Dental   `Note:` -  Prescription, Clinic and dental amounts must be preceded with the total healthcare amount and cannot occur individually.  Vision and Transit must be sent individually and cannot be combined with total healthcare amount or any other amounts. Total Healthcare amount can be sent individually.  Valid Values for **MasterCard**: - `prescription` - Amount Prescription/RX - `eligible-total` - Total Amount Healthcare   `Note:` -  Prescription must be preceded with the total healthcare amount and cannot occur individually. Total Healthcare amount can be sent individually. 

        :return: The amount_type of this Ptsv2paymentsHealthCareInformationAmountDetails.
        :rtype: str
        """
        return self._amount_type

    @amount_type.setter
    def amount_type(self, amount_type):
        """
        Sets the amount_type of this Ptsv2paymentsHealthCareInformationAmountDetails.
        Total amount that has been spent on healthcare in a transaction. Valid Values for **Visa**: - `healthcare` - Total Amount Healthcare - `healthcare-transit` - Amount Transit - `vision` - Amount Vision/Optical - `prescription` - Amount Prescription/RX - `clinic` - Amount Clinic/Other Qualified Medical - `dental` - Amount Dental   `Note:` -  Prescription, Clinic and dental amounts must be preceded with the total healthcare amount and cannot occur individually.  Vision and Transit must be sent individually and cannot be combined with total healthcare amount or any other amounts. Total Healthcare amount can be sent individually.  Valid Values for **MasterCard**: - `prescription` - Amount Prescription/RX - `eligible-total` - Total Amount Healthcare   `Note:` -  Prescription must be preceded with the total healthcare amount and cannot occur individually. Total Healthcare amount can be sent individually. 

        :param amount_type: The amount_type of this Ptsv2paymentsHealthCareInformationAmountDetails.
        :type: str
        """
        if amount_type is not None and len(amount_type) > 35:
            raise ValueError("Invalid value for `amount_type`, length must be less than or equal to `35`")

        self._amount_type = amount_type

    @property
    def amount(self):
        """
        Gets the amount of this Ptsv2paymentsHealthCareInformationAmountDetails.
        Total Amount that has been spent on transit healthcare. This is 13 byte field including sign. If the amount is positive, then it is a debit for the customer. If the amount is negative, then it is a credit for the customer. 

        :return: The amount of this Ptsv2paymentsHealthCareInformationAmountDetails.
        :rtype: str
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """
        Sets the amount of this Ptsv2paymentsHealthCareInformationAmountDetails.
        Total Amount that has been spent on transit healthcare. This is 13 byte field including sign. If the amount is positive, then it is a debit for the customer. If the amount is negative, then it is a credit for the customer. 

        :param amount: The amount of this Ptsv2paymentsHealthCareInformationAmountDetails.
        :type: str
        """
        if amount is not None and len(amount) > 13:
            raise ValueError("Invalid value for `amount`, length must be less than or equal to `13`")

        self._amount = amount

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Ptsv2paymentsHealthCareInformationAmountDetails):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
